# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/config.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2
from library.cpp.actors.protos import interconnect_pb2 as library_dot_cpp_dot_actors_dot_protos_dot_interconnect__pb2
from ydb.core.protos import blobstorage_pb2 as ydb_dot_core_dot_protos_dot_blobstorage__pb2
from ydb.core.protos import blobstorage_config_pb2 as ydb_dot_core_dot_protos_dot_blobstorage__config__pb2
from ydb.core.protos import blobstorage_vdisk_config_pb2 as ydb_dot_core_dot_protos_dot_blobstorage__vdisk__config__pb2
from ydb.core.protos import blobstorage_pdisk_config_pb2 as ydb_dot_core_dot_protos_dot_blobstorage__pdisk__config__pb2
from ydb.core.protos import cms_pb2 as ydb_dot_core_dot_protos_dot_cms__pb2
from ydb.core.protos import config_units_pb2 as ydb_dot_core_dot_protos_dot_config__units__pb2
from ydb.core.protos import counters_schemeshard_pb2 as ydb_dot_core_dot_protos_dot_counters__schemeshard__pb2
from ydb.core.protos import drivemodel_pb2 as ydb_dot_core_dot_protos_dot_drivemodel__pb2
from ydb.core.protos import flat_scheme_op_pb2 as ydb_dot_core_dot_protos_dot_flat__scheme__op__pb2
from ydb.core.protos import http_config_pb2 as ydb_dot_core_dot_protos_dot_http__config__pb2
from ydb.core.protos import hive_pb2 as ydb_dot_core_dot_protos_dot_hive__pb2
from ydb.core.protos import kqp_pb2 as ydb_dot_core_dot_protos_dot_kqp__pb2
from ydb.core.protos import netclassifier_pb2 as ydb_dot_core_dot_protos_dot_netclassifier__pb2
from ydb.core.protos import node_broker_pb2 as ydb_dot_core_dot_protos_dot_node__broker__pb2
from ydb.core.protos import pqconfig_pb2 as ydb_dot_core_dot_protos_dot_pqconfig__pb2
from ydb.core.protos import resource_broker_pb2 as ydb_dot_core_dot_protos_dot_resource__broker__pb2
from ydb.core.protos import shared_cache_pb2 as ydb_dot_core_dot_protos_dot_shared__cache__pb2
from ydb.core.protos import stream_pb2 as ydb_dot_core_dot_protos_dot_stream__pb2
from ydb.core.protos import tablet_pb2 as ydb_dot_core_dot_protos_dot_tablet__pb2
from ydb.core.protos import tablet_database_pb2 as ydb_dot_core_dot_protos_dot_tablet__database__pb2
from ydb.core.protos import tenant_pool_pb2 as ydb_dot_core_dot_protos_dot_tenant__pool__pb2
from ydb.core.protos import tenant_slot_broker_pb2 as ydb_dot_core_dot_protos_dot_tenant__slot__broker__pb2
from ydb.core.protos import auth_pb2 as ydb_dot_core_dot_protos_dot_auth__pb2
from ydb.core.protos import key_pb2 as ydb_dot_core_dot_protos_dot_key__pb2
from ydb.core.protos import alloc_pb2 as ydb_dot_core_dot_protos_dot_alloc__pb2
from ydb.core.protos import node_limits_pb2 as ydb_dot_core_dot_protos_dot_node__limits__pb2
from ydb.core.yq.libs.config.protos import fq_config_pb2 as ydb_dot_core_dot_yq_dot_libs_dot_config_dot_protos_dot_fq__config__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cydb/core/protos/config.proto\x12\rNKikimrConfig\x1a google/protobuf/descriptor.proto\x1a,library/cpp/actors/protos/interconnect.proto\x1a!ydb/core/protos/blobstorage.proto\x1a(ydb/core/protos/blobstorage_config.proto\x1a.ydb/core/protos/blobstorage_vdisk_config.proto\x1a.ydb/core/protos/blobstorage_pdisk_config.proto\x1a\x19ydb/core/protos/cms.proto\x1a\"ydb/core/protos/config_units.proto\x1a*ydb/core/protos/counters_schemeshard.proto\x1a ydb/core/protos/drivemodel.proto\x1a$ydb/core/protos/flat_scheme_op.proto\x1a!ydb/core/protos/http_config.proto\x1a\x1aydb/core/protos/hive.proto\x1a\x19ydb/core/protos/kqp.proto\x1a#ydb/core/protos/netclassifier.proto\x1a!ydb/core/protos/node_broker.proto\x1a\x1eydb/core/protos/pqconfig.proto\x1a%ydb/core/protos/resource_broker.proto\x1a\"ydb/core/protos/shared_cache.proto\x1a\x1cydb/core/protos/stream.proto\x1a\x1cydb/core/protos/tablet.proto\x1a%ydb/core/protos/tablet_database.proto\x1a!ydb/core/protos/tenant_pool.proto\x1a(ydb/core/protos/tenant_slot_broker.proto\x1a\x1aydb/core/protos/auth.proto\x1a\x19ydb/core/protos/key.proto\x1a\x1bydb/core/protos/alloc.proto\x1a!ydb/core/protos/node_limits.proto\x1a.ydb/core/yq/libs/config/protos/fq_config.proto\"?\n\tTAffinity\x12\t\n\x01X\x18\x01 \x03(\r\x12\x0f\n\x07\x43puList\x18\x02 \x01(\t\x12\x16\n\x0e\x45xcludeCpuList\x18\x03 \x01(\t\"\xd4\x0b\n\x12TActorSystemConfig\x12=\n\x08\x45xecutor\x18\x01 \x03(\x0b\x32+.NKikimrConfig.TActorSystemConfig.TExecutor\x12?\n\tScheduler\x18\x02 \x01(\x0b\x32,.NKikimrConfig.TActorSystemConfig.TScheduler\x12\x13\n\x0bSysExecutor\x18\x03 \x01(\r\x12\x14\n\x0cUserExecutor\x18\x04 \x01(\r\x12\x12\n\nIoExecutor\x18\x05 \x01(\r\x12\x15\n\rBatchExecutor\x18\x06 \x01(\r\x12K\n\x0fServiceExecutor\x18\x07 \x03(\x0b\x32\x32.NKikimrConfig.TActorSystemConfig.TServiceExecutor\x12\x1f\n\x17TimePerMailboxMicroSecs\x18\x08 \x01(\r\x12\x18\n\x10\x45ventsPerMailbox\x18\t \x01(\r\x12\x18\n\x10SelfPingInterval\x18\n \x01(\r\x12G\n\rUnitedWorkers\x18\x0b \x01(\x0b\x32\x30.NKikimrConfig.TActorSystemConfig.TUnitedWorkers\x1a\xfa\x03\n\tTExecutor\x12?\n\x04Type\x18\x01 \x01(\x0e\x32\x31.NKikimrConfig.TActorSystemConfig.TExecutor.EType\x12\x0f\n\x07Threads\x18\x02 \x01(\r\x12\x15\n\rSpinThreshold\x18\x03 \x01(\x04\x12*\n\x08\x41\x66\x66inity\x18\x04 \x01(\x0b\x32\x18.NKikimrConfig.TAffinity\x12\x1a\n\x12InjectMadSquirrels\x18\x05 \x01(\r\x12\x0c\n\x04Name\x18\x06 \x01(\t\x12\x1f\n\x17TimePerMailboxMicroSecs\x18\x07 \x01(\r\x12\x18\n\x10\x45ventsPerMailbox\x18\x08 \x01(\r\x12\x18\n\x10RealtimePriority\x18\t \x01(\r\x12\x13\n\x0b\x43oncurrency\x18\n \x01(\r\x12\x0e\n\x06Weight\x18\x0b \x01(\r\x12\x12\n\nMinThreads\x18\x0c \x01(\r\x12\x12\n\nMaxThreads\x18\r \x01(\r\x12\x19\n\x11\x42\x61lancingPriority\x18\x0e \x01(\r\x12\x1a\n\x12ToleratedLatencyUs\x18\x0f \x01(\x04\x12\x10\n\x08Priority\x18\x10 \x01(\x05\x12\x1b\n\x13MaxAvgPingDeviation\x18\x11 \x01(\x05\"&\n\x05\x45Type\x12\t\n\x05\x42\x41SIC\x10\x01\x12\x06\n\x02IO\x10\x02\x12\n\n\x06UNITED\x10\x03\x1a\x99\x01\n\nTScheduler\x12\x12\n\nResolution\x18\x01 \x01(\x04\x12\x15\n\rSpinThreshold\x18\x02 \x01(\x04\x12\x19\n\x11ProgressThreshold\x18\x03 \x01(\x04\x12*\n\x08\x41\x66\x66inity\x18\x04 \x01(\x0b\x32\x18.NKikimrConfig.TAffinity\x12\x19\n\x11UseSchedulerActor\x18\x05 \x01(\x08\x1a;\n\x10TServiceExecutor\x12\x13\n\x0bServiceName\x18\x01 \x02(\t\x12\x12\n\nExecutorId\x18\x02 \x02(\r\x1a\xa6\x02\n\x0eTUnitedWorkers\x12\x10\n\x08\x43puCount\x18\x01 \x01(\r\x12\x17\n\x0fSpinThresholdUs\x18\x02 \x01(\x04\x12\x13\n\x0bPoolLimitUs\x18\x03 \x01(\x04\x12\x14\n\x0c\x45ventLimitUs\x18\x04 \x01(\x04\x12\x18\n\x10LimitPrecisionUs\x18\x05 \x01(\x04\x12\x1a\n\x12\x46\x61stWorkerPriority\x18\x06 \x01(\x04\x12\x1a\n\x12IdleWorkerPriority\x18\x07 \x01(\x04\x12*\n\x08\x41\x66\x66inity\x18\x08 \x01(\x0b\x32\x18.NKikimrConfig.TAffinity\x12\x12\n\nNoRealtime\x18\t \x01(\x08\x12\x12\n\nNoAffinity\x18\n \x01(\x08\x12\x18\n\x10\x42\x61lancerPeriodUs\x18\x0b \x01(\x04\"\x84\x05\n\x18TStaticNameserviceConfig\x12;\n\x04Node\x18\x01 \x03(\x0b\x32-.NKikimrConfig.TStaticNameserviceConfig.TNode\x12\x13\n\x0b\x43lusterUUID\x18\x02 \x01(\t\x12\x12\n\nAcceptUUID\x18\x03 \x03(\t\x12\x1c\n\x14SuppressVersionCheck\x18\x04 \x01(\x08\x12\x46\n\x04Type\x18\x05 \x01(\x0e\x32\x38.NKikimrConfig.TStaticNameserviceConfig.ENameserviceType\x1a*\n\tTEndpoint\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x0f\n\x07\x41\x64\x64ress\x18\x02 \x01(\t\x1a\x98\x02\n\x05TNode\x12\x0e\n\x06NodeId\x18\x01 \x01(\r\x12\x0f\n\x07\x41\x64\x64ress\x18\x02 \x01(\t\x12\x0c\n\x04Port\x18\x03 \x01(\r\x12\x0c\n\x04Host\x18\x04 \x01(\t\x12\x18\n\x10InterconnectHost\x18\x05 \x01(\t\x12\x34\n\x08Location\x18\x06 \x01(\x0b\x32\".NActorsInterconnect.TNodeLocation\x12\x43\n\x08\x45ndpoint\x18\x07 \x03(\x0b\x32\x31.NKikimrConfig.TStaticNameserviceConfig.TEndpoint\x12=\n\rWalleLocation\x18\x08 \x01(\x0b\x32\".NActorsInterconnect.TNodeLocationB\x02\x18\x01\"U\n\x10\x45NameserviceType\x12\x0e\n\nNS_DEFAULT\x10\x00\x12\x0c\n\x08NS_FIXED\x10\x01\x12\x12\n\x0eNS_NODE_BROKER\x10\x02\x12\x0f\n\x0bNS_EXTERNAL\x10\x03\"\x7f\n\x19TDynamicNameserviceConfig\x12\x1d\n\x0fMaxStaticNodeId\x18\x01 \x01(\r:\x04\x31\x30\x30\x30\x12 \n\x10MaxDynamicNodeId\x18\x02 \x01(\r:\x06\x32\x30\x30\x30\x30\x30\x12!\n\rLeaseDuration\x18\x03 \x01(\x04:\n3600000000\"\xb6\x10\n\x0eTDomainsConfig\x12\x35\n\x06\x44omain\x18\x01 \x03(\x0b\x32%.NKikimrConfig.TDomainsConfig.TDomain\x12\x41\n\x0cStateStorage\x18\x02 \x03(\x0b\x32+.NKikimrConfig.TDomainsConfig.TStateStorage\x12;\n\tExecLevel\x18\x03 \x03(\x0b\x32(.NKikimrConfig.TDomainsConfig.TExecLevel\x12=\n\nHiveConfig\x18\x04 \x03(\x0b\x32).NKikimrConfig.TDomainsConfig.THiveConfig\x12S\n\x15NamedCompactionPolicy\x18\x05 \x03(\x0b\x32\x34.NKikimrConfig.TDomainsConfig.TNamedCompactionPolicy\x12\x45\n\x0eSecurityConfig\x18\x06 \x01(\x0b\x32-.NKikimrConfig.TDomainsConfig.TSecurityConfig\x12(\n\x1a\x46orbidImplicitStoragePools\x18\x07 \x01(\x08:\x04true\x1a\xe5\x02\n\rTStateStorage\x12\x0c\n\x04SSId\x18\x01 \x01(\r\x12?\n\x04Ring\x18\x02 \x01(\x0b\x32\x31.NKikimrConfig.TDomainsConfig.TStateStorage.TRing\x12\x1e\n\x13StateStorageVersion\x18\x03 \x01(\r:\x01\x30\x12\x1a\n\x12\x43ompatibleVersions\x18\x04 \x03(\r\x1a\xc8\x01\n\x05TRing\x12\x11\n\tNToSelect\x18\x01 \x01(\r\x12?\n\x04Ring\x18\x02 \x03(\x0b\x32\x31.NKikimrConfig.TDomainsConfig.TStateStorage.TRing\x12\x0c\n\x04Node\x18\x03 \x03(\r\x12\x1c\n\x14UseSingleNodeActorId\x18\x04 \x01(\x08\x12$\n\x1cUseRingSpecificNodeSelection\x18\x05 \x01(\x08\x12\x19\n\nIsDisabled\x18\x06 \x01(\x08:\x05\x66\x61lse\x1a\\\n\x10TStoragePoolType\x12\x0c\n\x04Kind\x18\x01 \x01(\t\x12:\n\nPoolConfig\x18\x02 \x01(\x0b\x32&.NKikimrBlobStorage.TDefineStoragePool\x1a\x9c\x04\n\x07TDomain\x12\x10\n\x08\x44omainId\x18\x01 \x01(\r\x12\x12\n\nSchemeRoot\x18\x02 \x01(\x06\x12\x13\n\x0b\x43oordinator\x18\x03 \x03(\x04\x12\x10\n\x08Mediator\x18\x04 \x03(\x04\x12\r\n\x05Proxy\x18\x05 \x03(\x04\x12\x0c\n\x04SSId\x18\x06 \x03(\r\x12\x0f\n\x07HiveUid\x18\x07 \x03(\r\x12\x16\n\x0ePlanResolution\x18\x08 \x01(\x04\x12\x0c\n\x04Name\x18\t \x01(\t\x12\x41\n\x08TxLimits\x18\n \x01(\x0b\x32/.NKikimrConfig.TDomainsConfig.TDomain.TTxLimits\x12H\n\x10StoragePoolTypes\x18\x0b \x03(\x0b\x32..NKikimrConfig.TDomainsConfig.TStoragePoolType\x12\x19\n\x11\x45xplicitMediators\x18\x0c \x03(\x06\x12\x1c\n\x14\x45xplicitCoordinators\x18\r \x03(\x06\x12\x1a\n\x12\x45xplicitAllocators\x18\x0e \x03(\x06\x12\x17\n\x0fSchemeBoardSSId\x18\x0f \x01(\r\x1au\n\tTTxLimits\x12\x1f\n\x17PerRequestDataSizeLimit\x18\x01 \x01(\x04\x12\x1d\n\x15PerShardReadSizeLimit\x18\x02 \x01(\x04\x12(\n PerShardIncomingReadSetSizeLimit\x18\x03 \x01(\x04\x1a,\n\x0bTHiveConfig\x12\x0f\n\x07HiveUid\x18\x01 \x01(\r\x12\x0c\n\x04Hive\x18\x02 \x01(\x06\x1a\x0c\n\nTExecLevel\x1aZ\n\x16TNamedCompactionPolicy\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x32\n\x06Policy\x18\x02 \x01(\x0b\x32\".NKikimrSchemeOp.TCompactionPolicy\x1a\xea\x03\n\x0fTSecurityConfig\x12*\n\x1b\x45nforceUserTokenRequirement\x18\x01 \x01(\x08:\x05\x66\x61lse\x12\x1d\n\x15MonitoringAllowedSIDs\x18\x02 \x03(\t\x12!\n\x19\x41\x64ministrationAllowedSIDs\x18\x03 \x03(\t\x12\x17\n\x0f\x44\x65\x66\x61ultUserSIDs\x18\x04 \x03(\t\x12\x1d\n\x15\x41llAuthenticatedUsers\x18\x05 \x01(\t\x12\x19\n\x11ViewerAllowedSIDs\x18\x06 \x03(\t\x12I\n\x0c\x44\x65\x66\x61ultUsers\x18\x0f \x03(\x0b\x32\x33.NKikimrConfig.TDomainsConfig.TSecurityConfig.TUser\x12K\n\rDefaultGroups\x18\x10 \x03(\x0b\x32\x34.NKikimrConfig.TDomainsConfig.TSecurityConfig.TGroup\x12\x15\n\rDefaultAccess\x18\x11 \x03(\t\x12\x15\n\rAllUsersGroup\x18\x12 \x01(\t\x1a\'\n\x05TUser\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x10\n\x08Password\x18\x02 \x01(\t\x1a\'\n\x06TGroup\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x0f\n\x07Members\x18\x02 \x03(\t\"\xcb\x01\n\x12TBlobStorageConfig\x12=\n\nServiceSet\x18\x01 \x01(\x0b\x32).NKikimrBlobStorage.TNodeWardenServiceSet\x12)\n\x1a\x45nableOverseerLsnReporting\x18\x02 \x01(\x08:\x05\x66\x61lse\x12\x15\n\rCacheFilePath\x18\x03 \x01(\t\x12\x19\n\x0b\x43\x61\x63hePDisks\x18\x04 \x01(\x08:\x04true\x12\x19\n\x0b\x43\x61\x63heVDisks\x18\x05 \x01(\x08:\x04true\"\xbe\x02\n\x18TBlobStorageFormatConfig\x12=\n\x05\x44rive\x18\x01 \x03(\x0b\x32..NKikimrConfig.TBlobStorageFormatConfig.TDrive\x1a\xe2\x01\n\x06TDrive\x12\x0e\n\x06RackId\x18\x01 \x01(\x04\x12\x0e\n\x06NodeId\x18\x02 \x01(\r\x12\x10\n\x08Hostname\x18\x03 \x01(\t\x12\x0c\n\x04Type\x18\x04 \x01(\t\x12\x0c\n\x04Path\x18\x05 \x01(\t\x12\x0c\n\x04Guid\x18\x06 \x01(\x04\x12\x0f\n\x07PDiskId\x18\x07 \x01(\x04\x12\x14\n\x0c\x44\x61taCenterId\x18\x08 \x01(\x04\x12\x0e\n\x06RoomId\x18\t \x01(\x04\x12\x0e\n\x06\x42odyId\x18\n \x01(\x04\x12\x35\n\x0bPDiskConfig\x18\x0b \x01(\x0b\x32 .NKikimrBlobStorage.TPDiskConfig\"\xf2\x01\n\x0fTUAClientConfig\x12\x0b\n\x03Uri\x18\x01 \x01(\t\x12\x17\n\x0fSharedSecretKey\x18\x02 \x01(\t\x12#\n\x10MaxInflightBytes\x18\x03 \x01(\x04:\t100000000\x12\x1c\n\x14GrpcReconnectDelayMs\x18\x04 \x01(\x04\x12\x17\n\x0fGrpcSendDelayMs\x18\x05 \x01(\x04\x12\x1a\n\x12GrpcMaxMessageSize\x18\x06 \x01(\x04\x12\x15\n\rClientLogFile\x18\x07 \x01(\t\x12\x19\n\x11\x43lientLogPriority\x18\x08 \x01(\r\x12\x0f\n\x07LogName\x18\t \x01(\t\"\xb5\x04\n\nTLogConfig\x12/\n\x05\x45ntry\x18\x01 \x03(\x0b\x32 .NKikimrConfig.TLogConfig.TEntry\x12\x15\n\x06SysLog\x18\x02 \x01(\x08:\x05\x66\x61lse\x12\x17\n\x0c\x44\x65\x66\x61ultLevel\x18\x03 \x01(\r:\x01\x35\x12\x1f\n\x14\x44\x65\x66\x61ultSamplingLevel\x18\x04 \x01(\r:\x01\x37\x12\x1e\n\x13\x44\x65\x66\x61ultSamplingRate\x18\x05 \x01(\r:\x01\x30\x12\x14\n\x06\x46ormat\x18\x06 \x01(\t:\x04\x66ull\x12\x13\n\x0b\x43lusterName\x18\x07 \x01(\t\x12\x1e\n\x10\x41llowDropEntries\x18\x08 \x01(\x08:\x04true\x12!\n\x12UseLocalTimestamps\x18\t \x01(\x08:\x05\x66\x61lse\x12\x17\n\x0f\x42\x61\x63kendFileName\x18\n \x01(\t\x12\x15\n\rSysLogService\x18\x0b \x01(\t\x12\x16\n\x0eSysLogToStdErr\x18\x0c \x01(\x08\x12\x36\n\x0eUAClientConfig\x18\r \x01(\x0b\x32\x1e.NKikimrConfig.TUAClientConfig\x12\x1d\n\x0fTimeThresholdMs\x18\x0e \x01(\x04:\x04\x31\x30\x30\x30\x12\x1f\n\x17IgnoreUnknownComponents\x18\x0f \x01(\x08\x1aW\n\x06TEntry\x12\x11\n\tComponent\x18\x01 \x01(\x0c\x12\r\n\x05Level\x18\x02 \x01(\r\x12\x15\n\rSamplingLevel\x18\x03 \x01(\r\x12\x14\n\x0cSamplingRate\x18\x04 \x01(\r\"6\n\x15TCompileServiceConfig\x12\x1d\n\rInflightLimit\x18\x01 \x01(\r:\x06\x31\x30\x30\x30\x30\x30\"\xbf\t\n\nTBootstrap\x12\x31\n\x06Tablet\x18\x01 \x03(\x0b\x32!.NKikimrConfig.TBootstrap.TTablet\x12\x1d\n\x15ProxySchemeCacheNodes\x18\x02 \x01(\x04\x12!\n\x19ProxySchemeCacheDistNodes\x18\x03 \x01(\x04\x12:\n\x10\x43ompactionBroker\x18\x04 \x01(\x0b\x32 .NKikimrTablet.TCompactionBroker\x12\x38\n\nNodeLimits\x18\x05 \x01(\x0b\x32$.NKikimrNodeLimits.TNodeLimitsConfig\x12\x44\n\x0eResourceBroker\x18\x06 \x01(\x0b\x32,.NKikimrResourceBroker.TResourceBrokerConfig\x12\x41\n\x11SharedCacheConfig\x18\x07 \x01(\x0b\x32&.NKikimrSharedCache.TSharedCacheConfig\x12;\n\x10ResourceProfiles\x18\x08 \x03(\x0b\x32!.NKikimrSchemeOp.TResourceProfile\x12\x42\n\x14\x43ompileServiceConfig\x18\t \x01(\x0b\x32$.NKikimrConfig.TCompileServiceConfig\x12\x1b\n\x13\x45nableIntrospection\x18\n \x01(\x08\x1a\xec\x01\n\x07TTablet\x12\x33\n\x04Type\x18\x01 \x01(\x0e\x32%.NKikimrConfig.TBootstrap.ETabletType\x12\x0c\n\x04Node\x18\x02 \x03(\r\x12\x33\n\x04Info\x18\x03 \x01(\x0b\x32%.NKikimrTabletBase.TTabletStorageInfo\x12\x0f\n\x07StandBy\x18\x04 \x01(\x08\x12\x16\n\x0eWatchThreshold\x18\x05 \x01(\x04\x12\x16\n\x0eStartFollowers\x18\x06 \x01(\x08\x12(\n\x19\x41llowDynamicConfiguration\x18\x07 \x01(\x08:\x05\x66\x61lse\"\xaf\x03\n\x0b\x45TabletType\x12\x0c\n\x08TX_DUMMY\x10\x00\x12\x08\n\x04HIVE\x10\x01\x12\x12\n\x0eTX_COORDINATOR\x10\n\x12\x0f\n\x0bTX_MEDIATOR\x10\x0b\x12\x0c\n\x08TX_PROXY\x10\x0c\x12\x17\n\x13\x46LAT_TX_COORDINATOR\x10\r\x12\r\n\tFLAT_HIVE\x10\x0e\x12\x16\n\x12\x46LAT_BS_CONTROLLER\x10\x0f\x12\x11\n\rFLAT_TX_PROXY\x10\x11\x12\x10\n\x0cTX_ALLOCATOR\x10\x12\x12\x17\n\x13\x42S_DOMAINCONTROLLER\x10\x14\x12\x0f\n\x0bSCHEMESHARD\x10\x1e\x12\r\n\tDATASHARD\x10\x1f\x12\x14\n\x10\x46LAT_SCHEMESHARD\x10 \x12\x10\n\x0cKEYVALUEFLAT\x10!\x12\x1a\n\x16JOBRUNNER_POOL_MANAGER\x10(\x12\x1f\n\x1b\x46LAT_JOBRUNNER_POOL_MANAGER\x10)\x12\x07\n\x03\x43MS\x10\x33\x12\x0f\n\x0bNODE_BROKER\x10\x34\x12\x16\n\x12TENANT_SLOT_BROKER\x10\x35\x12\x0b\n\x07\x43ONSOLE\x10\x36\x12\x13\n\x0e\x46\x41KE_DATASHARD\x10\xbc\x05\"\xb5\x0e\n\x13TInterconnectConfig\x12<\n\x07\x43hannel\x18\x01 \x03(\x0b\x32+.NKikimrConfig.TInterconnectConfig.TChannel\x12\x1a\n\x12\x46irstTryBeforePoll\x18\x02 \x01(\x08\x12\x17\n\x08StartTcp\x18\x03 \x01(\x08:\x05\x66\x61lse\x12\x15\n\rSelfKickDelay\x18\x04 \x01(\r\x12\x18\n\x10HandshakeTimeout\x18\x05 \x01(\r\x12\x19\n\x11HeartbeatInterval\x18\x06 \x01(\r\x12\x17\n\x0f\x44\x65\x61\x64PeerTimeout\x18\x07 \x01(\r\x12\x1e\n\x16SendBufferDieLimitInMB\x18\x08 \x01(\r\x12\x1a\n\x12\x43loseOnIdleTimeout\x18\t \x01(\r\x12#\n\x1bMaxInflightAmountOfDataInKB\x18\n \x01(\r\x12\x1c\n\x14MergePerPeerCounters\x18\x0b \x01(\x08\x12M\n\x10\x43ounterMergeMode\x18\x0f \x01(\x0e\x32-.NKikimrConfig.TInterconnectConfig.EMergeMode:\x04\x41UTO\x12\x1b\n\x13TCPSocketBufferSize\x18\x0c \x01(\r\x12\x1c\n\x14MaxTimePerEventInMks\x18\r \x01(\r\x12 \n\x12\x42indOnAllAddresses\x18\x10 \x01(\x08:\x04true\x12T\n\x0e\x45ncryptionMode\x18\x11 \x01(\x0e\x32\x32.NKikimrConfig.TInterconnectConfig.EEncryptionMode:\x08\x44ISABLED\x12\x13\n\x0bTlsAuthOnly\x18& \x01(\x08\x12\x1e\n\x16\x45nforceScopeValidation\x18\x12 \x01(\x08\x12\x13\n\x0b\x43\x65rtificate\x18\x1e \x01(\x0c\x12\x12\n\nPrivateKey\x18\x1f \x01(\x0c\x12\x1d\n\x15PathToCertificateFile\x18# \x01(\t\x12\x1c\n\x14PathToPrivateKeyFile\x18$ \x01(\t\x12\x14\n\x0cPathToCaFile\x18% \x01(\t\x12\x12\n\nCipherList\x18\" \x01(\t\x12<\n\x15MessagePendingTimeout\x18  \x01(\x0b\x32\x1d.NKikimrConfigUnits.TDuration\x12\x1a\n\x12MessagePendingSize\x18! \x01(\x04\x12(\n\x19SuppressConnectivityCheck\x18\' \x01(\x08:\x05\x66\x61lse\x12\x1e\n\x16PreallocatedBufferSize\x18( \x01(\r\x12\x1e\n\x16NumPreallocatedBuffers\x18) \x01(\r\x12\x1c\n\x14HandshakeBallastSize\x18\x0e \x01(\r\x12<\n\x15SelfKickDelayDuration\x18\x14 \x01(\x0b\x32\x1d.NKikimrConfigUnits.TDuration\x12?\n\x18HandshakeTimeoutDuration\x18\x15 \x01(\x0b\x32\x1d.NKikimrConfigUnits.TDuration\x12@\n\x19HeartbeatIntervalDuration\x18\x16 \x01(\x0b\x32\x1d.NKikimrConfigUnits.TDuration\x12>\n\x17\x44\x65\x61\x64PeerTimeoutDuration\x18\x17 \x01(\x0b\x32\x1d.NKikimrConfigUnits.TDuration\x12\x41\n\x1a\x43loseOnIdleTimeoutDuration\x18\x18 \x01(\x0b\x32\x1d.NKikimrConfigUnits.TDuration\x12!\n\x19TotalInflightAmountOfData\x18\x19 \x01(\x04\x12\x39\n\x12PingPeriodDuration\x18\x1a \x01(\x0b\x32\x1d.NKikimrConfigUnits.TDuration\x12\x41\n\x1a\x46orceConfirmPeriodDuration\x18\x1b \x01(\x0b\x32\x1d.NKikimrConfigUnits.TDuration\x12=\n\x16LostConnectionDuration\x18\x1c \x01(\x0b\x32\x1d.NKikimrConfigUnits.TDuration\x12:\n\x13\x42\x61tchPeriodDuration\x18\x1d \x01(\x0b\x32\x1d.NKikimrConfigUnits.TDuration\x1a\x38\n\x08TChannel\x12\r\n\x05Index\x18\x01 \x01(\r\x12\r\n\x05Quota\x18\x02 \x01(\r\x12\x0e\n\x06Weight\x18\x03 \x01(\r\"G\n\nEMergeMode\x12\x08\n\x04\x41UTO\x10\x00\x12\x0c\n\x08PER_PEER\x10\x01\x12\x13\n\x0fPER_DATA_CENTER\x10\x02\x12\x0c\n\x08NO_MERGE\x10\x03\";\n\x0f\x45\x45ncryptionMode\x12\x0c\n\x08\x44ISABLED\x10\x00\x12\x0c\n\x08OPTIONAL\x10\x01\x12\x0c\n\x08REQUIRED\x10\x02\"\xe0\x02\n\x15TChannelProfileConfig\x12>\n\x07Profile\x18\x01 \x03(\x0b\x32-.NKikimrConfig.TChannelProfileConfig.TProfile\x1a\x86\x02\n\x08TProfile\x12\x11\n\tProfileId\x18\x01 \x01(\r\x12G\n\x07\x43hannel\x18\x02 \x03(\x0b\x32\x36.NKikimrConfig.TChannelProfileConfig.TProfile.TChannel\x1a\x9d\x01\n\x08TChannel\x12\x16\n\x0e\x45rasureSpecies\x18\x01 \x01(\t\x12\x15\n\rPDiskCategory\x18\x02 \x01(\x04\x12I\n\rVDiskCategory\x18\x03 \x01(\x0e\x32).NKikimrBlobStorage.TVDiskKind.EVDiskKind:\x07\x44\x65\x66\x61ult\x12\x17\n\x0fStoragePoolKind\x18\x05 \x01(\t\"\xb1\x08\n\x11TMonitoringConfig\x12\x19\n\x0eMonitoringPort\x18\x01 \x01(\r:\x01\x30\x12\x1d\n\x11MonitoringThreads\x18\x02 \x01(\r:\x02\x31\x30\x12+\n\x11MonitoringCaption\x18\x03 \x01(\t:\x10YDB Developer UI\x12\"\n\x17TabletMonitoringRetries\x18\x04 \x01(\r:\x01\x31\x12\"\n\x13\x46orceDatabaseLabels\x18\x05 \x01(\x08:\x05\x66\x61lse\x12\x19\n\x11MonitoringAddress\x18\x06 \x01(\t\x12H\n\x0e\x44\x61tabaseLabels\x18\x07 \x01(\x0b\x32\x30.NKikimrConfig.TMonitoringConfig.TDatabaseLabels\x12Z\n\x17\x44\x61tabaseAttributeLabels\x18\x08 \x01(\x0b\x32\x39.NKikimrConfig.TMonitoringConfig.TDatabaseAttributeLabels\x12\x12\n\nDataCenter\x18\t \x01(\t\x12\x19\n\x11HostLabelOverride\x18\n \x01(\t\x12\x17\n\x0fProcessLocation\x18\x0b \x01(\t\x12\x13\n\x0b\x41llowOrigin\x18\x0c \x01(\t\x12\'\n\x12RedirectMainPageTo\x18\r \x01(\t:\x0bmonitoring/\x12\x1d\n\x15MonitoringCertificate\x18\x0e \x01(\t\x12!\n\x19MonitoringCertificateFile\x18\x0f \x01(\t\x1a\xa6\x02\n\x0fTDatabaseLabels\x12\x15\n\x07\x45nabled\x18\x01 \x01(\x08:\x04true\x12\x10\n\x08Services\x18\x02 \x03(\t\x12\'\n\x17NoneDatabasetLabelValue\x18\x04 \x01(\t:\x06<none>\x12.\n\x1aMultipleDatabaseLabelValue\x18\x05 \x01(\t:\n<multiple>\x12$\n\x14StaticSlotLabelValue\x18\x07 \x01(\t:\x06static\x12&\n\x15\x44ynamicSlotLabelValue\x18\x08 \x01(\t:\x07\x64ynamic\x12*\n\x16MultipleSlotLabelValue\x18\t \x01(\t:\n<multiple>\x12\x17\n\x0fGroupAllMetrics\x18\n \x01(\x08\x1a\xba\x01\n\x18TDatabaseAttributeLabels\x12\x15\n\x07\x45nabled\x18\x01 \x01(\x08:\x04true\x12\x62\n\x0f\x41ttributeGroups\x18\x02 \x03(\x0b\x32I.NKikimrConfig.TMonitoringConfig.TDatabaseAttributeLabels.TAttributeGroup\x1a#\n\x0fTAttributeGroup\x12\x10\n\x08Services\x18\x02 \x03(\t\"3\n\x14TRestartsCountConfig\x12\x1b\n\x11RestartsCountFile\x18\x01 \x01(\t:\x00\"\x88\t\n\x11TMessageBusConfig\x12\x1c\n\rStartBusProxy\x18\x01 \x01(\x08:\x05\x66\x61lse\x12\x1b\n\x0c\x42usProxyPort\x18\x02 \x01(\r:\x05\x31\x34\x35\x30\x35\x12M\n\x13ProxyBusQueueConfig\x18\x03 \x01(\x0b\x32\x30.NKikimrConfig.TMessageBusConfig.TBusQueueConfig\x12Q\n\x15ProxyBusSessionConfig\x18\x04 \x01(\x0b\x32\x32.NKikimrConfig.TMessageBusConfig.TBusSessionConfig\x12\x18\n\x10ProxyBindToProxy\x18\x05 \x03(\x04\x12\"\n\x14StartTracingBusProxy\x18\x06 \x01(\x08:\x04true\x12\x11\n\tTracePath\x18\x07 \x01(\t\x12/\n\x1f\x43ompileInflightLimit_Depricated\x18\x08 \x01(\x04:\x06\x31\x30\x30\x30\x30\x30\x1a\x36\n\x0fTBusQueueConfig\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x15\n\nNumWorkers\x18\x02 \x01(\r:\x01\x31\x1a\xdb\x05\n\x11TBusSessionConfig\x12\x0e\n\x04Name\x18\x01 \x01(\t:\x00\x12\x15\n\nNumRetries\x18\x02 \x01(\r:\x01\x30\x12\x1b\n\rRetryInterval\x18\x03 \x01(\r:\x04\x31\x30\x30\x30\x12 \n\x11ReconnectWhenIdle\x18\x04 \x01(\x08:\x05\x66\x61lse\x12\x19\n\x0bMaxInFlight\x18\x05 \x01(\x04:\x04\x31\x30\x30\x30\x12#\n\x18PerConnectionMaxInFlight\x18\x06 \x01(\r:\x01\x30\x12)\n\x1ePerConnectionMaxInFlightBySize\x18\x07 \x01(\r:\x01\x30\x12\x1d\n\x11MaxInFlightBySize\x18\x08 \x01(\x03:\x02-1\x12\x17\n\x0cTotalTimeout\x18\t \x01(\x03:\x01\x30\x12\x16\n\x0bSendTimeout\x18\n \x01(\x03:\x01\x30\x12\x19\n\x0e\x43onnectTimeout\x18\x0b \x01(\x03:\x01\x30\x12 \n\x11\x44\x65\x66\x61ultBufferSize\x18\x0c \x01(\x04:\x05\x31\x30\x32\x34\x30\x12\x1e\n\rMaxBufferSize\x18\r \x01(\x04:\x07\x31\x30\x34\x38\x35\x37\x36\x12\x1f\n\x14SocketRecvBufferSize\x18\x0e \x01(\r:\x01\x30\x12\x1f\n\x14SocketSendBufferSize\x18\x0f \x01(\r:\x01\x30\x12\x15\n\tSocketToS\x18\x10 \x01(\x05:\x02-1\x12\x1c\n\rSendThreshold\x18\x11 \x01(\x04:\x05\x31\x30\x32\x34\x30\x12\x0f\n\x04\x43ork\x18\x12 \x01(\x04:\x01\x30\x12 \n\x0eMaxMessageSize\x18\x13 \x01(\r:\x08\x32\x37\x32\x36\x32\x39\x37\x36\x12\x19\n\nTcpNoDelay\x18\x14 \x01(\x08:\x05\x66\x61lse\x12\x16\n\x07TcpCork\x18\x15 \x01(\x08:\x05\x66\x61lse\x12*\n\x1c\x45xecuteOnMessageInWorkerPool\x18\x16 \x01(\x08:\x04true\x12(\n\x1a\x45xecuteOnReplyInWorkerPool\x18\x17 \x01(\x08:\x04true\x12\x15\n\nListenPort\x18\x18 \x01(\r:\x01\x30\"\xcd\x01\n\x0eTTabletsConfig\x12\x35\n\x06Tablet\x18\x01 \x03(\x0b\x32%.NKikimrConfig.TTabletsConfig.TTablet\x1a\x83\x01\n\x07TTablet\x12\x0c\n\x04Type\x18\x01 \x01(\t\x12\x0c\n\x04Node\x18\x02 \x03(\r\x12\x33\n\x04Info\x18\x03 \x01(\x0b\x32%.NKikimrTabletBase.TTabletStorageInfo\x12\x0f\n\x07StandBy\x18\x04 \x01(\x08\x12\x16\n\x0eWatchThreshold\x18\x05 \x01(\x04\"M\n\nTKQPConfig\x12\x14\n\x06\x45nable\x18\x01 \x01(\x08:\x04true\x12)\n\x08Settings\x18\n \x03(\x0b\x32\x17.NKikimrKqp.TKqpSetting\"b\n\x16TInternalRequestConfig\x12\"\n\x17RetryPeriodStartSeconds\x18\x01 \x01(\r:\x01\x33\x12$\n\x18RetryPeriodFinishSeconds\x18\x02 \x01(\r:\x02\x33\x30\"\x9e\x01\n\x17TMetadataProviderConfig\x12\x15\n\x07\x45nabled\x18\x01 \x01(\x08:\x04true\x12 \n\x14RefreshPeriodSeconds\x18\x02 \x01(\r:\x02\x31\x30\x12<\n\rRequestConfig\x18\x03 \x01(\x0b\x32%.NKikimrConfig.TInternalRequestConfig\x12\x0c\n\x04Path\x18\x04 \x01(\t\"\x81\x02\n\x16TBackgroundTasksConfig\x12\x15\n\x07\x45nabled\x18\x01 \x01(\x08:\x04true\x12<\n\rRequestConfig\x18\x02 \x01(\x0b\x32%.NKikimrConfig.TInternalRequestConfig\x12\x1d\n\x11PullPeriodSeconds\x18\x03 \x01(\r:\x02\x31\x30\x12\x1c\n\x11PingPeriodSeconds\x18\x04 \x01(\r:\x01\x32\x12\"\n\x16PingCheckPeriodSeconds\x18\x05 \x01(\r:\x02\x32\x30\x12\x16\n\x0bMaxInFlight\x18\x06 \x01(\r:\x01\x38\x12\x19\n\x11InternalTablePath\x18\x07 \x01(\t\"?\n\x10TMemoryLogConfig\x12\x15\n\rLogBufferSize\x18\x01 \x01(\x04\x12\x14\n\x0cLogGrainSize\x18\x02 \x01(\x04\"\xb0\x07\n\x0bTGRpcConfig\x12\x1c\n\x0eStartGRpcProxy\x18\x01 \x01(\x08:\x04true\x12\x12\n\x04Host\x18\x02 \x01(\t:\x04[::]\x12\x0c\n\x04Port\x18\x03 \x01(\r\x12\x18\n\rWorkerThreads\x18\x04 \x01(\r:\x01\x32\x12(\n\x14GRpcMemoryQuotaBytes\x18\x05 \x01(\x04:\n1073741824\x12\x16\n\x0eMaxMessageSize\x18\x06 \x01(\x04\x12\x13\n\x0bMaxInFlight\x18\x07 \x01(\r\x12\x38\n\x0fStreamingConfig\x18\x08 \x01(\x0b\x32\x1f.NKikimrStream.TStreamingConfig\x12\x0f\n\x07SslPort\x18\t \x01(\r\x12\n\n\x02\x43\x41\x18\n \x01(\t\x12\x0c\n\x04\x43\x65rt\x18\x0b \x01(\t\x12\x0b\n\x03Key\x18\x0c \x01(\t\x12\x1d\n\x15PathToCertificateFile\x18\x1b \x01(\t\x12\x1c\n\x14PathToPrivateKeyFile\x18\x1c \x01(\t\x12\x14\n\x0cPathToCaFile\x18\x1d \x01(\t\x12\x12\n\nPublicHost\x18\r \x01(\t\x12\x12\n\nPublicPort\x18\x0e \x01(\r\x12\x15\n\rPublicSslPort\x18\x0f \x01(\r\x12\x19\n\x11PublicAddressesV4\x18\x10 \x03(\t\x12\x19\n\x11PublicAddressesV6\x18\x11 \x03(\t\x12 \n\x18PublicTargetNameOverride\x18\x12 \x01(\t\x12\x10\n\x08Services\x18\x14 \x03(\t\x12\x1e\n\x10ServeRootDomains\x18\x15 \x01(\x08:\x04true\x12\x17\n\x0fServicesEnabled\x18\x16 \x03(\t\x12\x18\n\x10ServicesDisabled\x18\x17 \x03(\t\x12\x1e\n\x0fSkipSchemeCheck\x18\x18 \x01(\x08:\x05\x66\x61lse\x12\"\n\x1aRatelimiterServicesEnabled\x18\x19 \x03(\t\x12#\n\x1bRatelimiterServicesDisabled\x18\x1a \x03(\t\x12\x1d\n\x0fKeepAliveEnable\x18\x64 \x01(\x08:\x04true\x12*\n\x1eKeepAliveIdleTimeoutTriggerSec\x18\x65 \x01(\r:\x02\x39\x30\x12!\n\x16KeepAliveMaxProbeCount\x18\x66 \x01(\r:\x01\x33\x12%\n\x19KeepAliveProbeIntervalSec\x18g \x01(\r:\x02\x31\x30\x12\x31\n\x0c\x45xtEndpoints\x18\xc8\x01 \x03(\x0b\x32\x1a.NKikimrConfig.TGRpcConfig\"\xb4\x01\n\x12TDynamicNodeConfig\x12\x19\n\x11NodeBrokerAddress\x18\x01 \x01(\t\x12\x12\n\nDomainName\x18\x02 \x01(\t\x12\x18\n\x10InterconnectPort\x18\x03 \x01(\r\x12.\n\x08NodeInfo\x18\x04 \x01(\x0b\x32\x1c.NKikimrNodeBroker.TNodeInfo\x12\x13\n\x0bNodeAddress\x18\x05 \x01(\t\x12\x10\n\x08NodeHost\x18\x06 \x01(\t\"\xbb\x1c\n\rTFeatureFlags\x12\x30\n\"EnableSeparateSolomonShardForPDisk\x18\x01 \x01(\x08:\x04true\x12\x32\n$UseForsetiSchedulerByDefaultForPDisk\x18\x02 \x01(\x08:\x04true\x12.\n EnableSeparateTrimThreadForPDisk\x18\x03 \x01(\x08:\x04true\x12\x30\n\"EnableSeparateSubmitThreadForPDisk\x18\x04 \x01(\x08:\x04true\x12/\n EnablePerOwnerChunkLimitForPDisk\x18\x05 \x01(\x08:\x05\x66\x61lse\x12(\n\x19TrimEntireDeviceOnStartup\x18\x06 \x01(\x08:\x05\x66\x61lse\x12&\n\x18\x45nableChunkGraceForPDisk\x18\x07 \x01(\x08:\x04true\x12\x35\n\'AllowConsistentOperationsForSchemeShard\x18\x08 \x01(\x08:\x04true\x12\x1f\n\x11\x45nableSchemeBoard\x18\t \x01(\x08:\x04true\x12-\n\x1f\x41llowYdbRequestsWithoutDatabase\x18\n \x01(\x08:\x04true\x12&\n\x18\x45nableExternalSubdomains\x18\x0b \x01(\x08:\x04true\x12!\n\x13\x41llowRecursiveMkDir\x18\x0c \x01(\x08:\x04true\x12&\n\x18\x41llowHugeKeyValueDeletes\x18\r \x01(\x08:\x04true\x12*\n\x1cSendSchemaVersionToDatashard\x18\x0e \x01(\x08:\x04true\x12$\n\x16\x45nableSchemeBoardCache\x18\x0f \x01(\x08:\x04true\x12\x1f\n\x11\x45nableSystemViews\x18\x10 \x01(\x08:\x04true\x12 \n\x12\x45nableExternalHive\x18\x11 \x01(\x08:\x04true\x12\x32\n$UseSchemeBoardCacheForSchemeRequests\x18\x12 \x01(\x08:\x04true\x12\'\n\x19\x43ompileMinikqlWithVersion\x18\x13 \x01(\x08:\x04true\x12#\n\x15ReadTableWithSnapshot\x18\x14 \x01(\x08:\x04true\x12+\n\x1dImportantTabletsUseSystemPool\x18\x15 \x01(\x08:\x04true\x12!\n\x13\x45nableOfflineSlaves\x18\x16 \x01(\x08:\x04true\x12,\n\x1d\x43heckDatabaseAccessPermission\x18\x17 \x01(\x08:\x05\x66\x61lse\x12#\n\x15\x41llowOnlineIndexBuild\x18\x18 \x01(\x08:\x04true\x12(\n\x1a\x45nablePersistentQueryStats\x18\x19 \x01(\x08:\x04true\x12&\n\x17\x44isableDataShardBarrier\x18\x1a \x01(\x08:\x05\x66\x61lse\x12-\n\x1f\x45nablePutBatchingForBlobStorage\x18\x1b \x01(\x08:\x04true\x12\x1f\n\x11\x45nableKqpWideFlow\x18\x1c \x01(\x08:\x04true\x12\"\n\x14\x45nableKqpScanQueries\x18\x1d \x01(\x08:\x04true\x12-\n\x1e\x45nablePersistentPartitionStats\x18\x1e \x01(\x08:\x05\x66\x61lse\x12&\n\x18\x45nableTtlOnIndexedTables\x18\x1f \x01(\x08:\x04true\x12<\n-AllowUpdateChannelsBindingOfSolomonPartitions\x18  \x01(\x08:\x05\x66\x61lse\x12\x1e\n\x10\x44isableLegacyYql\x18! \x01(\x08:\x04true\x12+\n\x1d\x45nableDataColumnForIndexTable\x18\" \x01(\x08:\x04true\x12:\n+AllowServerlessStorageBillingForSchemeShard\x18# \x01(\x08:\x05\x66\x61lse\x12$\n\x16\x45nableGracefulShutdown\x18$ \x01(\x08:\x04true\x12#\n\x15\x45nableDrainOnShutdown\x18% \x01(\x08:\x04true\x12\'\n\x18\x45nableConfigurationCache\x18& \x01(\x08:\x05\x66\x61lse\x12\x1f\n\x10\x45nableDbCounters\x18\' \x01(\x08:\x05\x66\x61lse\x12\x35\n&EnableClockGettimeForUserCpuAccounting\x18( \x01(\x08:\x05\x66\x61lse\x12 \n\x12\x45nableAsyncIndexes\x18) \x01(\x08:\x04true\x12)\n\x1b\x41llowStreamExecuteYqlScript\x18* \x01(\x08:\x04true\x12\x31\n#EnableKqpScanOverPersistentSnapshot\x18+ \x01(\x08:\x04true\x12(\n\x1a\x45nableOlapSchemaOperations\x18, \x01(\x08:\x04true\x12\x1b\n\x0c\x45nableVPatch\x18- \x01(\x08:\x05\x66\x61lse\x12%\n\x17\x45nableMvccSnapshotReads\x18. \x01(\x08:\x04true\x12\x44\n\nEnableMvcc\x18/ \x01(\x0e\x32$.NKikimrConfig.TFeatureFlags.Tribool:\nVALUE_TRUE\x12\x33\n%EnableSchemeTransactionsAtSchemeShard\x18\x30 \x01(\x08:\x04true\x12+\n\x1c\x45nableArrowFormatAtDatashard\x18\x31 \x01(\x08:\x05\x66\x61lse\x12\x39\n*Enable3x3RequestsForMirror3DCMinLatencyPut\x18\x32 \x01(\x08:\x05\x66\x61lse\x12(\n\x1a\x45nableBackgroundCompaction\x18\x33 \x01(\x08:\x04true\x12*\n\x1b\x45nableArrowFormatInChannels\x18\x34 \x01(\x08:\x05\x66\x61lse\x12\x33\n$EnableBackgroundCompactionServerless\x18\x35 \x01(\x08:\x05\x66\x61lse\x12\"\n\x14\x45nableNotNullColumns\x18\x36 \x01(\x08:\x04true\x12+\n\x1d\x45nableTtlOnAsyncIndexedTables\x18\x37 \x01(\x08:\x04true\x12\x32\n$EnableBulkUpsertToAsyncIndexedTables\x18\x38 \x01(\x08:\x04true\x12.\n EnableNodeBrokerSingleDomainMode\x18\x39 \x01(\x08:\x04true\x12+\n\x1c\x45nablePublicApiExternalBlobs\x18; \x01(\x08:\x05\x66\x61lse\x12*\n\x1b\x45nablePublicApiKeepInMemory\x18< \x01(\x08:\x05\x66\x61lse\x12.\n EnableImplicitScanQueryInScripts\x18= \x01(\x08:\x04true\x12\x32\n$EnablePredicateExtractForScanQueries\x18> \x01(\x08:\x04true\x12\x1e\n\x10\x41llowVDiskDefrag\x18? \x01(\x08:\x04true\x12 \n\x12\x45nableAsyncHttpMon\x18@ \x01(\x08:\x04true\x12\x1f\n\x11\x45nableChangefeeds\x18\x41 \x01(\x08:\x04true\x12-\n\x1e\x45nableKqpScanQueryStreamLookup\x18\x42 \x01(\x08:\x05\x66\x61lse\x12\x38\n)EnableKqpScanQueryMultipleOlapShardsReads\x18\x43 \x01(\x08:\x05\x66\x61lse\x12\x32\n$EnablePredicateExtractForDataQueries\x18\x44 \x01(\x08:\x04true\x12\x1e\n\x0f\x45nableMoveIndex\x18\x46 \x01(\x08:\x05\x66\x61lse\x12\x30\n!EnableFailureInjectionTermination\x18G \x01(\x08:\x05\x66\x61lse\x12!\n\x12\x45nableChunkLocking\x18H \x01(\x08:\x05\x66\x61lse\x12\'\n\x18\x45nableNotNullDataColumns\x18I \x01(\x08:\x05\x66\x61lse\x12\x1e\n\x0f\x45nableGrpcAudit\x18J \x01(\x08:\x05\x66\x61lse\x12-\n\x1e\x45nableKqpDataQueryStreamLookup\x18K \x01(\x08:\x05\x66\x61lse\x12+\n\x1d\x45nableBorrowedSplitCompaction\x18L \x01(\x08:\x04true\x12*\n\x1b\x45nableChangefeedInitialScan\x18M \x01(\x08:\x05\x66\x61lse\x12-\n\x1e\x45nableDynamicNodeAuthorization\x18O \x01(\x08:\x05\x66\x61lse\x12(\n\x19\x45nableKqpImmediateEffects\x18P \x01(\x08:\x05\x66\x61lse\x12-\n\x1e\x45nableDataShardGenericReadSets\x18Q \x01(\x08:\x05\x66\x61lse\x12\x31\n\"EnableAlterDatabaseCreateHiveFirst\x18R \x01(\x08:\x05\x66\x61lse\x12)\n\x1b\x45nableSmallDiskOptimization\x18T \x01(\x08:\x04true\x12\x32\n#EnableDataShardVolatileTransactions\x18U \x01(\x08:\x05\x66\x61lse\"5\n\x07Tribool\x12\t\n\x05UNSET\x10\x00\x12\x0e\n\nVALUE_TRUE\x10\x01\x12\x0f\n\x0bVALUE_FALSE\x10\x02J\x04\x08:\x10;J\x04\x08\x45\x10\x46J\x04\x08N\x10OJ\x04\x08S\x10T\"\xdb\x01\n\x10THttpProxyConfig\x12\x0f\n\x07\x45nabled\x18\x01 \x01(\x08\x12\x0c\n\x04Port\x18\x02 \x01(\r\x12\x0e\n\x06Secure\x18\x03 \x01(\x08\x12\n\n\x02\x43\x41\x18\x04 \x01(\t\x12\x0c\n\x04\x43\x65rt\x18\x05 \x01(\t\x12\x0b\n\x03Key\x18\x06 \x01(\t\x12 \n\x18YandexCloudServiceRegion\x18\x07 \x03(\t\x12\x1f\n\x17IamTokenServiceEndpoint\x18\x08 \x01(\t\x12\x1d\n\x15\x41\x63\x63\x65ssServiceEndpoint\x18\t \x01(\t\x12\x0f\n\x07JwtFile\x18\n \x01(\t\"\xd5\"\n\nTSqsConfig\x12\x11\n\tEnableSqs\x18\x05 \x01(\x08\x12\x17\n\x04Root\x18\x01 \x01(\t:\t/Root/SQS\x12\x10\n\x08\x45ndpoint\x18\x03 \x01(\t\x12:\n\x10HttpServerConfig\x18\x04 \x01(\x0b\x32 .NKikimrConfig.THttpServerConfig\x12\x1f\n\x11\x45nableQueueMaster\x18\x06 \x01(\x08:\x04true\x12\x1f\n\x11\x45nableQueueLeader\x18\x44 \x01(\x08:\x04true\x12)\n\x1aQueueAttributesCacheTimeMs\x18\x08 \x01(\x04:\x05\x36\x30\x30\x30\x30\x12\x1f\n\x11SlowRequestTimeMs\x18\t \x01(\x04:\x04\x32\x35\x30\x30\x12\x1f\n\x10MaxWaitTimeoutMs\x18\n \x01(\x04:\x05\x32\x30\x30\x30\x30\x12,\n!SchemeCacheSoftRefreshTimeSeconds\x18\x0b \x01(\r:\x01\x35\x12-\n!SchemeCacheHardRefreshTimeSeconds\x18\x0c \x01(\r:\x02\x31\x30\x12!\n\x12\x46orceAccessControl\x18\r \x01(\x08:\x05\x66\x61lse\x12$\n\x1c\x41\x63\x63ountsWithoutMandatoryAuth\x18\x0e \x03(\t\x12\x1e\n\x0fYandexCloudMode\x18\x0f \x01(\x08:\x05\x66\x61lse\x12\x1c\n\x14YandexCloudServiceId\x18\x10 \x01(\r\x12\'\n\x1fYandexCloudAccessServiceAddress\x18\x1d \x01(\t\x12\'\n\x1fYandexCloudFolderServiceAddress\x18\x1e \x01(\t\x12-\n\x18YandexCloudServiceRegion\x18\' \x01(\t:\x0bru-central1\x12(\n\x1aMeteringFlushingIntervalMs\x18\x33 \x01(\r:\x04\x35\x30\x30\x30\x12\x1b\n\x13MeteringLogFilePath\x18\x34 \x01(\t\x12\x1c\n\x14MeteringCloudNetCidr\x18\x35 \x03(\t\x12\x1d\n\x15MeteringYandexNetCidr\x18\x36 \x03(\t\x12+\n\x1cMastersDescriberUpdateTimeMs\x18\x11 \x01(\r:\x05\x31\x30\x30\x30\x30\x12%\n\x16MasterConnectTimeoutMs\x18\x12 \x01(\r:\x05\x31\x30\x30\x30\x30\x12+\n\x1cLeadersDescriberUpdateTimeMs\x18\x45 \x01(\r:\x05\x31\x30\x30\x30\x30\x12%\n\x16LeaderConnectTimeoutMs\x18\x46 \x01(\r:\x05\x31\x30\x30\x30\x30\x12*\n\x1bMinMessageRetentionPeriodMs\x18\x13 \x01(\x04:\x05\x36\x30\x30\x30\x30\x12#\n\x14TransactionTimeoutMs\x18\x14 \x01(\x04:\x05\x32\x30\x30\x30\x30\x12+\n\x1eTransactionRetryWaitDurationMs\x18\x15 \x01(\x04:\x03\x35\x30\x30\x12/\n!TransactionMaxRetryWaitDurationMs\x18\x16 \x01(\x04:\x04\x32\x35\x30\x30\x12,\n\x1d\x42\x61\x63kgroundMetricsUpdateTimeMs\x18\x17 \x01(\x04:\x05\x31\x30\x30\x30\x30\x12&\n\x1aMaxNumberOfReceiveMessages\x18\x18 \x01(\x04:\x02\x31\x30\x12 \n\x10RequestTimeoutMs\x18\x19 \x01(\x04:\x06\x36\x30\x30\x30\x30\x30\x12\"\n\x14\x46orceQueueCreationV2\x18\x1a \x01(\x08:\x04true\x12\"\n\x14\x46orceQueueDeletionV2\x18\x1b \x01(\x08:\x04true\x12%\n\x16\x45nableDeadLetterQueues\x18) \x01(\x08:\x05\x66\x61lse\x12$\n\x1c\x43reateLegacyDurationCounters\x18\x1c \x01(\x08\x12.\n\"MinTimeLeftForReceiveMessageWaitMs\x18\x1f \x01(\x04:\x02\x36\x34\x12&\n\x1e\x43heckAllShardsInReceiveMessage\x18  \x01(\x08\x12\x1f\n\x0f\x43leanupPeriodMs\x18! \x01(\x04:\x06\x31\x35\x30\x30\x30\x30\x12\x1e\n\x10\x43leanupBatchSize\x18\" \x01(\x04:\x04\x31\x30\x30\x30\x12%\n\x15\x44\x65\x64uplicationPeriodMs\x18# \x01(\x04:\x06\x33\x30\x30\x30\x30\x30\x12,\n\x1cGroupsReadAttemptIdsPeriodMs\x18$ \x01(\x04:\x06\x33\x30\x30\x30\x30\x30\x12%\n\x17GroupSelectionBatchSize\x18& \x01(\x04:\x04\x31\x30\x30\x30\x12\"\n\x14\x44oAutomaticMigration\x18% \x01(\x08:\x04true\x12(\n\x1a\x41\x64\x64MesagesToInflyBatchSize\x18( \x01(\x04:\x04\x32\x30\x30\x30\x12M\n\x1aStdQueueSendBatchingPolicy\x18* \x01(\x0b\x32).NKikimrConfig.TSqsConfig.TBatchingPolicy\x12N\n\x1b\x46ifoQueueSendBatchingPolicy\x18+ \x01(\x0b\x32).NKikimrConfig.TSqsConfig.TBatchingPolicy\x12O\n\x1cStdQueueDeleteBatchingPolicy\x18, \x01(\x0b\x32).NKikimrConfig.TSqsConfig.TBatchingPolicy\x12P\n\x1d\x46ifoQueueDeleteBatchingPolicy\x18- \x01(\x0b\x32).NKikimrConfig.TSqsConfig.TBatchingPolicy\x12M\n\x1aStdQueueLoadBatchingPolicy\x18. \x01(\x0b\x32).NKikimrConfig.TSqsConfig.TBatchingPolicy\x12?\n\rQuotingConfig\x18/ \x01(\x0b\x32(.NKikimrConfig.TSqsConfig.TQuotingConfig\x12-\n\x1f\x45nableQueueAttributesValidation\x18\x30 \x01(\x08:\x04true\x12S\n\x17\x41\x63\x63ountSettingsDefaults\x18\x31 \x01(\x0b\x32\x32.NKikimrConfig.TSqsConfig.TAccountSettingsDefaults\x12\"\n\x1a\x41llowYandexAttributePrefix\x18\x32 \x01(\x08\x12\"\n\x1aQueueCountersExportDelayMs\x18\x37 \x01(\x04\x12 \n\x12\x43reateLazyCounters\x18\x38 \x01(\x08:\x04true\x12\'\n\x18UserSettingsUpdateTimeMs\x18\x39 \x01(\x04:\x05\x36\x30\x30\x30\x30\x12\'\n\x19UserSettingsReadBatchSize\x18: \x01(\x04:\x04\x31\x30\x30\x30\x12%\n\x17QueuesListReadBatchSize\x18; \x01(\x04:\x04\x31\x30\x30\x30\x12\x1b\n\x13ValidateMessageBody\x18< \x01(\x08\x12+\n\x1c\x44lqNotificationGracePeriodMs\x18= \x01(\x04:\x05\x36\x30\x30\x30\x30\x12.\n\x1f\x41\x64\x64MessagesToInflyCheckPeriodMs\x18> \x01(\x04:\x05\x33\x30\x30\x30\x30\x12.\n\"AddMessagesToInflyMinCheckAttempts\x18? \x01(\x04:\x02\x31\x30\x12&\n\x18MinimumGarbageAgeSeconds\x18@ \x01(\x04:\x04\x33\x36\x30\x30\x12*\n\x1bMeteringByNetClassifierOnly\x18\x41 \x01(\x08:\x05\x66\x61lse\x12M\n\x14YcSearchEventsConfig\x18\x42 \x01(\x0b\x32/.NKikimrConfig.TSqsConfig.TYcSearchEventsConfig\x12<\n\nAuthConfig\x18\x43 \x01(\x0b\x32(.NKikimrConfig.TSqsConfig.TYdbAuthConfig\x1aS\n\x0fTBatchingPolicy\x12\x16\n\tBatchSize\x18\x01 \x01(\x04:\x03\x32\x30\x30\x12(\n\x1cTransactionsMaxInflyPerShard\x18\x02 \x01(\x04:\x02\x32\x30\x1a\xbf\x06\n\x0eTQuotingConfig\x12\x15\n\rEnableQuoting\x18\x01 \x01(\x08\x12\x17\n\x0fQuotaDeadlineMs\x18\x02 \x01(\x04\x12`\n\x16LocalRateLimiterConfig\x18\x03 \x01(\x0b\x32@.NKikimrConfig.TSqsConfig.TQuotingConfig.TLocalRateLimiterConfig\x12V\n\x11KesusQuoterConfig\x18\x04 \x01(\x0b\x32;.NKikimrConfig.TSqsConfig.TQuotingConfig.TKesusQuoterConfig\x1a\xed\x02\n\x14TDefaultActionsRates\x12\x1a\n\x12StdSendMessageRate\x18\x01 \x01(\r\x12\x1d\n\x15StdReceiveMessageRate\x18\x02 \x01(\r\x12\x1c\n\x14StdDeleteMessageRate\x18\x03 \x01(\r\x12&\n\x1eStdChangeMessageVisibilityRate\x18\x04 \x01(\r\x12\x1b\n\x13\x46ifoSendMessageRate\x18\x05 \x01(\r\x12\x1e\n\x16\x46ifoReceiveMessageRate\x18\x06 \x01(\r\x12\x1d\n\x15\x46ifoDeleteMessageRate\x18\x07 \x01(\r\x12\'\n\x1f\x46ifoChangeMessageVisibilityRate\x18\x08 \x01(\r\x12\x19\n\x11\x43reateObjectsRate\x18\t \x01(\r\x12\x19\n\x11\x44\x65leteObjectsRate\x18\n \x01(\r\x12\x19\n\x11OtherRequestsRate\x18\x0b \x01(\r\x1ag\n\x17TLocalRateLimiterConfig\x12L\n\x05Rates\x18\x01 \x01(\x0b\x32=.NKikimrConfig.TSqsConfig.TQuotingConfig.TDefaultActionsRates\x1aj\n\x12TKesusQuoterConfig\x12T\n\rDefaultLimits\x18\x01 \x01(\x0b\x32=.NKikimrConfig.TSqsConfig.TQuotingConfig.TDefaultActionsRates\x1a\x36\n\x18TAccountSettingsDefaults\x12\x1a\n\x0eMaxQueuesCount\x18\x01 \x01(\x03:\x02\x35\x30\x1a\xe0\x01\n\x15TYcSearchEventsConfig\x12\x1d\n\x0e\x45nableYcSearch\x18\x01 \x01(\x08:\x05\x66\x61lse\x12\x19\n\x0fUnifiedAgentUri\x18\n \x01(\tH\x00\x12\x18\n\x0eOutputFileName\x18\x0b \x01(\tH\x00\x12!\n\x15RescanIntervalSeconds\x18\x03 \x01(\x04:\x02\x36\x30\x12%\n\x16ReindexIntervalSeconds\x18\x04 \x01(\x04:\x05\x31\x34\x34\x30\x30\x12\x19\n\nTenantMode\x18\x05 \x01(\x08:\x05\x66\x61lseB\x0e\n\x0cOutputMethod\x1a&\n\x11TOauthTokenConfig\x12\x11\n\tTokenFile\x18\x01 \x02(\t\x1a\x32\n\nTJwtConfig\x12\x0f\n\x07JwtFile\x18\x01 \x02(\t\x12\x13\n\x0bIamEndpoint\x18\x02 \x01(\t\x1a\x9b\x01\n\x0eTYdbAuthConfig\x12\x41\n\nOauthToken\x18\x01 \x01(\x0b\x32+.NKikimrConfig.TSqsConfig.TOauthTokenConfigH\x00\x12\x33\n\x03Jwt\x18\x02 \x01(\x0b\x32$.NKikimrConfig.TSqsConfig.TJwtConfigH\x00\x42\x11\n\x0fLocalAuthConfig\"\x1a\n\x18TConfigsDispatcherConfig\"_\n\x11TCompactionPolicy\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12<\n\x10\x43ompactionPolicy\x18\x02 \x01(\x0b\x32\".NKikimrSchemeOp.TCompactionPolicy\"\xa4\x02\n\x10TExecutionPolicy\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x38\n\x0ePipelineConfig\x18\x02 \x01(\x0b\x32 .NKikimrSchemeOp.TPipelineConfig\x12\x17\n\x0fResourceProfile\x18\x03 \x01(\t\x12 \n\x11\x45nableFilterByKey\x18\x04 \x01(\x08:\x05\x66\x61lse\x12#\n\x15\x45xecutorFastLogPolicy\x18\x05 \x01(\x08:\x04true\x12\x17\n\x0fTxReadSizeLimit\x18\x06 \x01(\x04\x12\x18\n\x10\x45nableEraseCache\x18\x07 \x01(\x08\x12\x19\n\x11\x45raseCacheMinRows\x18\x08 \x01(\r\x12\x1a\n\x12\x45raseCacheMaxBytes\x18\t \x01(\r\"\x9a\x01\n\x13TPartitioningPolicy\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x1e\n\x16UniformPartitionsCount\x18\x02 \x01(\r\x12\x11\n\tAutoSplit\x18\x03 \x01(\x08\x12\x11\n\tAutoMerge\x18\x04 \x01(\x08\x12\x13\n\x0bSizeToSplit\x18\x05 \x01(\x04\x12\x1a\n\x12MaxPartitionsCount\x18\x06 \x01(\x04\"[\n\x0eTStoragePolicy\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12;\n\x0e\x43olumnFamilies\x18\x02 \x03(\x0b\x32#.NKikimrSchemeOp.TFamilyDescription\"x\n\x12TReplicationPolicy\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x15\n\rFollowerCount\x18\x02 \x01(\x04\x12$\n\x16\x41llowFollowerPromotion\x18\x03 \x01(\x08:\x04true\x12\x17\n\x0f\x43rossDataCenter\x18\x04 \x01(\x08\"9\n\x0eTCachingPolicy\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x19\n\x11\x45xecutorCacheSize\x18\x02 \x01(\x04\"\xb5\x01\n\rTTableProfile\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x18\n\x10\x43ompactionPolicy\x18\x02 \x01(\t\x12\x17\n\x0f\x45xecutionPolicy\x18\x03 \x01(\t\x12\x1a\n\x12PartitioningPolicy\x18\x04 \x01(\t\x12\x15\n\rStoragePolicy\x18\x05 \x01(\t\x12\x19\n\x11ReplicationPolicy\x18\x06 \x01(\t\x12\x15\n\rCachingPolicy\x18\x07 \x01(\t\"\xb7\x03\n\x14TTableProfilesConfig\x12\x33\n\rTableProfiles\x18\x01 \x03(\x0b\x32\x1c.NKikimrConfig.TTableProfile\x12<\n\x12\x43ompactionPolicies\x18\x02 \x03(\x0b\x32 .NKikimrConfig.TCompactionPolicy\x12:\n\x11\x45xecutionPolicies\x18\x03 \x03(\x0b\x32\x1f.NKikimrConfig.TExecutionPolicy\x12@\n\x14PartitioningPolicies\x18\x04 \x03(\x0b\x32\".NKikimrConfig.TPartitioningPolicy\x12\x36\n\x0fStoragePolicies\x18\x05 \x03(\x0b\x32\x1d.NKikimrConfig.TStoragePolicy\x12>\n\x13ReplicationPolicies\x18\x06 \x03(\x0b\x32!.NKikimrConfig.TReplicationPolicy\x12\x36\n\x0f\x43\x61\x63hingPolicies\x18\x07 \x03(\x0b\x32\x1d.NKikimrConfig.TCachingPolicy\"\x90\x1f\n\x13TTableServiceConfig\x12\x17\n\x0fQueryLimitBytes\x18\x01 \x01(\r\x12\x1c\n\x14ParametersLimitBytes\x18\x02 \x01(\r\x12\x1c\n\x14SessionsLimitPerNode\x18\x03 \x01(\r\x12#\n\x15\x43ompileQueryCacheSize\x18\x06 \x01(\r:\x04\x31\x30\x30\x30\x12#\n\x18\x43ompileMaxActiveRequests\x18\x07 \x01(\r:\x01\x34\x12%\n\x17\x43ompileRequestQueueSize\x18\x08 \x01(\r:\x04\x31\x30\x30\x30\x12$\n\x16UseSchemeCacheMetadata\x18\t \x01(\x08:\x04true\x12\"\n\x14UseSessionBusyStatus\x18\n \x01(\x08:\x04true\x12\x1f\n\x10\x43ompileTimeoutMs\x18\x0c \x01(\r:\x05\x36\x30\x30\x30\x30\x12L\n\x0fResourceManager\x18\r \x01(\x0b\x32\x33.NKikimrConfig.TTableServiceConfig.TResourceManager\x12\x44\n\x0bQueryLimits\x18\x0e \x01(\x0b\x32/.NKikimrConfig.TTableServiceConfig.TQueryLimits\x12\x12\n\nSqlVersion\x18\x0f \x01(\r\x12X\n\x15SpillingServiceConfig\x18\x10 \x01(\x0b\x32\x39.NKikimrConfig.TTableServiceConfig.TSpillingServiceConfig\x12N\n\x10ShutdownSettings\x18\x11 \x01(\x0b\x32\x34.NKikimrConfig.TTableServiceConfig.TShutdownSettings\x12\\\n\x17SessionBalancerSettings\x18\x12 \x01(\x0b\x32;.NKikimrConfig.TTableServiceConfig.TSessionBalancerSettings\x12\"\n\x17\x43ompileQueryCacheTTLSec\x18\x14 \x01(\r:\x01\x30\x12P\n\x11QueryReplayConfig\x18\x15 \x01(\x0b\x32\x35.NKikimrConfig.TTableServiceConfig.TQueryReplayConfig\x12+\n\x1c\x45nableKqpScanQuerySourceRead\x18\x1a \x01(\x08:\x05\x66\x61lse\x12+\n\x1c\x45nableKqpDataQuerySourceRead\x18\x1b \x01(\x08:\x05\x66\x61lse\x12\'\n\x1aSessionIdleDurationSeconds\x18\x1c \x01(\x04:\x03\x36\x30\x30\x1a\xc2\x01\n\x15TShardsScanningPolicy\x12$\n\x17\x41ggregationGroupByLimit\x18\x01 \x01(\r:\x03\x32\x35\x36\x12%\n\x17\x41ggregationNoGroupLimit\x18\x02 \x01(\r:\x04\x31\x30\x32\x34\x12\x15\n\tScanLimit\x18\x03 \x01(\r:\x02\x31\x36\x12(\n\x19ParallelScanningAvailable\x18\x04 \x01(\x08:\x05\x66\x61lse\x12\x1b\n\x10ShardSplitFactor\x18\x05 \x01(\r:\x01\x31\x1a\xb0\x04\n\x10TResourceManager\x12 \n\x12\x43omputeActorsCount\x18\x01 \x01(\r:\x04\x31\x30\x30\x30\x12\"\n\x11\x43hannelBufferSize\x18\x02 \x01(\x04:\x07\x38\x33\x38\x38\x36\x30\x38\x12-\n\x1bMkqlLightProgramMemoryLimit\x18\x04 \x01(\x04:\x08\x33\x31\x34\x35\x37\x32\x38\x30\x12-\n\x1bMkqlHeavyProgramMemoryLimit\x18\x05 \x01(\x04:\x08\x33\x31\x34\x35\x37\x32\x38\x30\x12%\n\x10QueryMemoryLimit\x18\x06 \x01(\x04:\x0b\x33\x32\x32\x31\x32\x32\x35\x34\x37\x32\x30\x12\'\n\x1cPublishStatisticsIntervalSec\x18\x07 \x01(\r:\x01\x32\x12*\n\x1c\x45nableInstantMkqlMemoryAlloc\x18\x08 \x01(\x08:\x04true\x12.\n\x1aMaxTotalChannelBuffersSize\x18\x0b \x01(\x04:\n2147483648\x12%\n\x14MinChannelBufferSize\x18\x0c \x01(\x04:\x07\x32\x30\x39\x37\x31\x35\x32\x12V\n\x14ShardsScanningPolicy\x18\x10 \x01(\x0b\x32\x38.NKikimrConfig.TTableServiceConfig.TShardsScanningPolicy\x12/\n\x1cKqpPatternCacheCapacityBytes\x18\x11 \x01(\x04:\t104857600J\x04\x08\x03\x10\x04J\x04\x08\t\x10\nJ\x04\x08\n\x10\x0bJ\x04\x08\r\x10\x0eJ\x04\x08\x0e\x10\x0f\x1a\xf5\x03\n\x16TSpillingServiceConfig\x12\x63\n\x0fLocalFileConfig\x18\x01 \x01(\x0b\x32J.NKikimrConfig.TTableServiceConfig.TSpillingServiceConfig.TLocalFileConfig\x1a\xf5\x02\n\x10TLocalFileConfig\x12\x15\n\x06\x45nable\x18\x01 \x01(\x08:\x05\x66\x61lse\x12#\n\x04Root\x18\x02 \x01(\t:\x15/tmp/kikimr_spilling/\x12!\n\x0cMaxTotalSize\x18\x03 \x01(\x04:\x0b\x32\x31\x34\x37\x34\x38\x33\x36\x34\x38\x30\x12\x1f\n\x0bMaxFileSize\x18\x04 \x01(\x04:\n5368709120\x12\"\n\x0fMaxFilePartSize\x18\x05 \x01(\x04:\t104857600\x12t\n\x0cIoThreadPool\x18\x06 \x01(\x0b\x32^.NKikimrConfig.TTableServiceConfig.TSpillingServiceConfig.TLocalFileConfig.TIoThreadPoolConfig\x1aG\n\x13TIoThreadPoolConfig\x12\x17\n\x0cWorkersCount\x18\x01 \x01(\r:\x01\x32\x12\x17\n\tQueueSize\x18\x02 \x01(\r:\x04\x31\x30\x30\x30\x1a\x91\x01\n\x11TQueryPhaseLimits\x12\x1b\n\x13\x41\x66\x66\x65\x63tedShardsLimit\x18\x01 \x01(\r\x12\x19\n\x11ReadsetCountLimit\x18\x02 \x01(\r\x12#\n\x1b\x43omputeNodeMemoryLimitBytes\x18\x03 \x01(\x04\x12\x1f\n\x17TotalReadSizeLimitBytes\x18\x04 \x01(\x04\x1a\xe0\x01\n\x0cTQueryLimits\x12I\n\x0bPhaseLimits\x18\x01 \x01(\x0b\x32\x34.NKikimrConfig.TTableServiceConfig.TQueryPhaseLimits\x12$\n\x14SchemeQueryTimeoutMs\x18\x02 \x01(\r:\x06\x36\x30\x30\x30\x30\x30\x12\"\n\x12\x44\x61taQueryTimeoutMs\x18\x03 \x01(\r:\x06\x33\x30\x30\x30\x30\x30\x12\"\n\x12ScanQueryTimeoutMs\x18\x04 \x01(\r:\x06\x36\x30\x30\x30\x30\x30\x12\x17\n\x0fResultRowsLimit\x18\x05 \x01(\r\x1ap\n\x11TShutdownSettings\x12 \n\x11ShutdownTimeoutMs\x18\x01 \x01(\r:\x05\x33\x30\x30\x30\x30\x12\x1c\n\rHardTimeoutMs\x18\x02 \x01(\r:\x05\x31\x30\x30\x30\x30\x12\x1b\n\rSoftTimeoutMs\x18\x03 \x01(\r:\x04\x32\x30\x30\x30\x1a\x8f\x07\n\x18TSessionBalancerSettings\x12\x16\n\x07\x45nabled\x18\x01 \x01(\x08:\x05\x66\x61lse\x12*\n\x1fMaxSessionsShutdownInFlightSize\x18\x02 \x01(\r:\x01\x31\x12\x19\n\rMinCVTreshold\x18\x03 \x01(\r:\x02\x31\x30\x12\x19\n\rMaxCVTreshold\x18\x04 \x01(\r:\x02\x32\x30\x12+\n\x1cHardSessionShutdownTimeoutMs\x18\x05 \x01(\r:\x05\x33\x30\x30\x30\x30\x12+\n\x1cSoftSessionShutdownTimeoutMs\x18\x06 \x01(\r:\x05\x31\x35\x30\x30\x30\x12\x1b\n\x0fMinNodeSessions\x18\x07 \x01(\r:\x02\x31\x30\x12#\n\x15LocalDatacenterPolicy\x18\x08 \x01(\x08:\x04true\x12$\n\x17MinCpuBalancerThreshold\x18\t \x01(\x01:\x03\x30.5\x12$\n\x16\x42oardPublishIntervalMs\x18\n \x01(\r:\x04\x31\x30\x30\x30\x12$\n\x15\x42oardLookupIntervalMs\x18\x0b \x01(\r:\x05\x33\x30\x30\x30\x30\x12\x83\x01\n\nEnableTier\x18\x0c \x01(\x0e\x32G.NKikimrConfig.TTableServiceConfig.TSessionBalancerSettings.EEnableTier:&TIER_ENABLED_FOR_SESSIONS_WITH_SUPPORT\x12r\n\x08Strategy\x18\r \x01(\x0e\x32N.NKikimrConfig.TTableServiceConfig.TSessionBalancerSettings.EBalancingStrategy:\x10\x42\x41LANCE_BY_COUNT\x12+\n\x1cSupportRemoteSessionCreation\x18\x0e \x01(\x08:\x05\x66\x61lse\"f\n\x0b\x45\x45nableTier\x12\x11\n\rTIER_DISABLED\x10\x01\x12*\n&TIER_ENABLED_FOR_SESSIONS_WITH_SUPPORT\x10\x02\x12\x18\n\x14TIER_ENABLED_FOR_ALL\x10\x03\"\\\n\x12\x45\x42\x61lancingStrategy\x12\x12\n\x0e\x42\x41LANCE_BY_CPU\x10\x01\x12\x14\n\x10\x42\x41LANCE_BY_COUNT\x10\x02\x12\x1c\n\x18\x42\x41LANCE_BY_CPU_AND_COUNT\x10\x03\x1a\x83\x02\n\x12TQueryReplayConfig\x12\x16\n\x07\x45nabled\x18\x01 \x01(\x08:\x05\x66\x61lse\x12;\n\x0fUnifiedAgentUri\x18\x02 \x01(\t:\"unix:///tmp/ydb-cp-replay-log.sock\x12\x1f\n\x14GrpcMaxMessageSizeMB\x18\x03 \x01(\r:\x01\x38\x12\x1a\n\x0fInflightLimitMB\x18\x04 \x01(\r:\x01\x38\x12(\n\x1aLeakyBucketQuotaBucketSize\x18\x05 \x01(\r:\x04\x31\x30\x30\x30\x12\x31\n%LeakyBucketQuotaBucketDurationSeconds\x18\x06 \x01(\r:\x02\x36\x30J\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06J\x04\x08\x0b\x10\x0cJ\x04\x08\x13\x10\x14J\x04\x08\x16\x10\x17J\x04\x08\x17\x10\x18J\x04\x08\x18\x10\x19J\x04\x08\x19\x10\x1a\"i\n\x18TImmediateControlOptions\x12\x13\n\x0b\x44\x65scription\x18\x01 \x01(\t\x12\x10\n\x08MinValue\x18\x02 \x01(\x04\x12\x10\n\x08MaxValue\x18\x03 \x01(\x04\x12\x14\n\x0c\x44\x65\x66\x61ultValue\x18\x04 \x01(\x04\"\xba\x17\n\x18TImmediateControlsConfig\x12U\n\x11\x44\x61taShardControls\x18\x01 \x01(\x0b\x32:.NKikimrConfig.TImmediateControlsConfig.TDataShardControls\x12Q\n\x0fTxLimitControls\x18\x02 \x01(\x0b\x32\x38.NKikimrConfig.TImmediateControlsConfig.TTxLimitControls\x12Y\n\x13\x43oordinatorControls\x18\x03 \x01(\x0b\x32<.NKikimrConfig.TImmediateControlsConfig.TCoordinatorControls\x12Y\n\x13SchemeShardControls\x18\x04 \x01(\x0b\x32<.NKikimrConfig.TImmediateControlsConfig.TSchemeShardControls\x1a\xb5\r\n\x12TDataShardControls\x12I\n\nMaxTxInFly\x18\x01 \x01(\x04\x42\x35\xca\xe4\x1d\x31\n&Maximum tx queue size for single shard\x10\x00\x18\xa0\x8d\x06 \x98u\x12Q\n\x12\x44isableByKeyFilter\x18\x02 \x01(\x04\x42\x35\xca\xe4\x1d\x31\n)Disable bloom filter usage on row selects\x10\x00\x18\x01 \x00\x12l\n\x14MaxTxLagMilliseconds\x18\x03 \x01(\x04\x42N\xca\xe4\x1dJ\n<Max lag in tx plan execution before shard becomes overloaded\x10\x00\x18\x80\x90\xfb\xd3\t \xe0\xa7\x12\x12\x63\n\x17\x43\x61nCancelROWithReadSets\x18\x04 \x01(\x04\x42\x42\xca\xe4\x1d>\n6Allow to cancel RO tx with output read sets by timeout\x10\x00\x18\x01 \x00\x12j\n\rDataTxProfile\x18\x05 \x01(\x0b\x32S.NKikimrConfig.TImmediateControlsConfig.TDataShardControls.TExecutionProfileOptions\x12W\n\x11\x42\x61\x63kupReadAheadLo\x18\x06 \x01(\x04\x42<\xca\xe4\x1d\x38\n-Override for backup readahead (low watermark)\x10\x00\x18\x80\x80\x80  \x00\x12X\n\x11\x42\x61\x63kupReadAheadHi\x18\x07 \x01(\x04\x42=\xca\xe4\x1d\x39\n.Override for backup readahead (high watermark)\x10\x00\x18\x80\x80\x80@ \x00\x12o\n\x1cPrioritizedMvccSnapshotReads\x18\x08 \x01(\x04\x42I\xca\xe4\x1d\x45\n=Enables prioritized mvcc snapshot reads over immediate writes\x10\x00\x18\x01 \x01\x12j\n\x1cUnprotectedMvccSnapshotReads\x18\t \x01(\x04\x42\x44\xca\xe4\x1d@\n8Enables unprotected (fully readonly) mvcc snapshot reads\x10\x00\x18\x01 \x01\x12^\n\x12\x45nableLeaderLeases\x18\n \x01(\x04\x42\x42\xca\xe4\x1d>\n6Enables leader leases for processing read-only queries\x10\x00\x18\x01 \x01\x12\x65\n\x18MinLeaderLeaseDurationUs\x18\x0b \x01(\x04\x42\x43\xca\xe4\x1d?\n1The minimum leader lease duration in microseconds\x10\xe8\x07\x18\xc0\x96\xb1\x02 \x90\xa1\x0f\x12Q\n\x0eTtlReadAheadLo\x18\x0c \x01(\x04\x42\x39\xca\xe4\x1d\x35\n*Override for ttl readahead (low watermark)\x10\x00\x18\x80\x80\x80  \x00\x12R\n\x0eTtlReadAheadHi\x18\r \x01(\x04\x42:\xca\xe4\x1d\x36\n+Override for ttl readahead (high watermark)\x10\x00\x18\x80\x80\x80@ \x00\x12U\n\x12\x45nableLockedWrites\x18\x0e \x01(\x04\x42\x39\xca\xe4\x1d\x35\n-Enables experimental persistent locked writes\x10\x00\x18\x01 \x00\x12\x61\n\x15MaxLockedWritesPerKey\x18\x0f \x01(\x04\x42\x42\xca\xe4\x1d>\n3Maximum number of uncommitted locked writes per key\x10\x00\x18\xc0\x84= \xe8\x07\x1a\x89\x02\n\x18TExecutionProfileOptions\x12P\n\x0eLogThresholdMs\x18\x01 \x01(\x04\x42\x38\xca\xe4\x1d\x34\n)Log execution profile for slow operations\x10\x00\x18\x80\xb8\x99) \x00\x12U\n\x11\x42ufferThresholdMs\x18\x02 \x01(\x04\x42:\xca\xe4\x1d\x36\n+Store execution profile for slow operations\x10\x00\x18\x80\xb8\x99) \x00\x12\x44\n\nBufferSize\x18\x03 \x01(\x04\x42\x30\xca\xe4\x1d,\n#Slow operation profiles buffer size\x10\x00\x18\xe8\x07 d\x1a\xa4\x03\n\x10TTxLimitControls\x12^\n\x17PerRequestDataSizeLimit\x18\x01 \x01(\x04\x42=\xca\xe4\x1d\x39\n&Maximum read data size per transaction\x10\x00\x18\x80\x80\xc0\xa8\xca\x9a: \x80\x80\x80\x80\xc8\x01\x12\x64\n\x15PerShardReadSizeLimit\x18\x02 \x01(\x04\x42\x45\xca\xe4\x1d\x41\n0Maximum read data size per transaction per shard\x10\x00\x18\x80\x80\x80\x80\x90\x03 \x80\x80\x80\x80\x14\x12s\n PerShardIncomingReadSetSizeLimit\x18\x03 \x01(\x04\x42I\xca\xe4\x1d\x45\n6Maximum input read sets size per transaction per shard\x10\x00\x18\x80\x80\x80\x80\x14 \x80\x80\x80\x64\x12U\n\x10\x44\x65\x66\x61ultTimeoutMs\x18\x04 \x01(\x04\x42;\xca\xe4\x1d\x37\n*Default execution timeout for transactions\x10\x00\x18\x80\xdd\xdb\x01 \xe0\xd4\x03\x1a\xdd\x01\n\x14TCoordinatorControls\x12^\n\x12\x45nableLeaderLeases\x18\x01 \x01(\x04\x42\x42\xca\xe4\x1d>\n6Enables leader leases for processing read-only queries\x10\x00\x18\x01 \x01\x12\x65\n\x18MinLeaderLeaseDurationUs\x18\x02 \x01(\x04\x42\x43\xca\xe4\x1d?\n1The minimum leader lease duration in microseconds\x10\xe8\x07\x18\xc0\x96\xb1\x02 \x90\xa1\x0f\x1a\xfe\x01\n\x14TSchemeShardControls\x12\x83\x01\n\x17\x46orceShardSplitDataSize\x18\x01 \x01(\x04\x42\x62\xca\xe4\x1d^\nKForces shards to split when reaching the given data size (2 GiB by default)\x10\x80\x80\x80\x05\x18\x80\x80\x80\x80@ \x80\x80\x80\x80\x08\x12`\n\x16\x44isableForceShardSplit\x18\x02 \x01(\x04\x42@\xca\xe4\x1d<\n4Disables forced shard splits, for special cases only\x10\x00\x18\x01 \x00\"E\n\x0fTMeteringConfig\x12\x18\n\x10MeteringFilePath\x18\x01 \x01(\t\x12\x18\n\x10SystemBackupSIDs\x18\x02 \x03(\t\"\xb2\x01\n\x0cTAuditConfig\x12\x15\n\rAuditFilePath\x18\x01 \x01(\t\x12\x39\n\x06\x46ormat\x18\x02 \x01(\x0e\x32#.NKikimrConfig.TAuditConfig.EFormat:\x04JSON\x12\x0f\n\x07LogName\x18\x03 \x01(\t\x12!\n\x12UnifiedAgentEnable\x18\x04 \x01(\x08:\x05\x66\x61lse\"\x1c\n\x07\x45\x46ormat\x12\x08\n\x04JSON\x10\x01\x12\x07\n\x03TXT\x10\x02\"Y\n\x10THiveTabletLimit\x12\x33\n\x04Type\x18\x01 \x01(\x0e\x32%.NKikimrTabletBase.TTabletTypes.EType\x12\x10\n\x08MaxCount\x18\x02 \x01(\x04\"\x90\x01\n\x15THiveTabletPreference\x12\x33\n\x04Type\x18\x01 \x01(\x0e\x32%.NKikimrTabletBase.TTabletTypes.EType\x12\x42\n\x15\x44\x61taCentersPreference\x18\n \x01(\x0b\x32#.NKikimrHive.TDataCentersPreference\"\x83\x1a\n\x0bTHiveConfig\x12 \n\x13MaxTabletsScheduled\x18\x02 \x01(\x04:\x03\x31\x30\x30\x12%\n\x12MaxResourceCounter\x18\x03 \x01(\x04:\t100000000\x12 \n\x0eMaxResourceCPU\x18\x04 \x01(\x04:\x08\x31\x30\x30\x30\x30\x30\x30\x30\x12\'\n\x11MaxResourceMemory\x18\x05 \x01(\x04:\x0c\x35\x31\x32\x30\x30\x30\x30\x30\x30\x30\x30\x30\x12&\n\x12MaxResourceNetwork\x18\x06 \x01(\x04:\n1000000000\x12 \n\x13MinScatterToBalance\x18\x07 \x01(\x01:\x03\x30.5\x12\x1e\n\x10SpreadNeighbours\x18\x08 \x01(\x08:\x04true\x12\x1e\n\x10MaxBootBatchSize\x18\t \x01(\x04:\x04\x31\x30\x30\x30\x12\x19\n\rDrainInflight\x18\n \x01(\x04:\x02\x31\x30\x12\x1a\n\x0f\x44\x65\x66\x61ultUnitIOPS\x18\x0b \x01(\x01:\x01\x31\x12#\n\x15\x44\x65\x66\x61ultUnitThroughput\x18\x0c \x01(\x04:\x04\x31\x30\x30\x30\x12\"\n\x0f\x44\x65\x66\x61ultUnitSize\x18\r \x01(\x04:\t100000000\x12\x1c\n\x11StorageOvercommit\x18\x0e \x01(\x01:\x01\x31\x12z\n\x16StorageBalanceStrategy\x18\x0f \x01(\x0e\x32\x36.NKikimrConfig.THiveConfig.EHiveStorageBalanceStrategy:\"HIVE_STORAGE_BALANCE_STRATEGY_SIZE\x12\x1d\n\x0fStorageSafeMode\x18\x10 \x01(\x08:\x04true\x12\x82\x01\n\x15StorageSelectStrategy\x18\x11 \x01(\x0e\x32\x35.NKikimrConfig.THiveConfig.EHiveStorageSelectStrategy:,HIVE_STORAGE_SELECT_STRATEGY_WEIGHTED_RANDOM\x12!\n\x13RequestSequenceSize\x18\x12 \x01(\x04:\x04\x31\x30\x30\x30\x12$\n\x16MinRequestSequenceSize\x18\x13 \x01(\x04:\x04\x31\x30\x30\x30\x12\'\n\x16MaxRequestSequenceSize\x18\x14 \x01(\x04:\x07\x31\x30\x30\x30\x30\x30\x30\x12 \n\x11MetricsWindowSize\x18\x15 \x01(\x04:\x05\x36\x30\x30\x30\x30\x12\x1f\n\x12MaxNodeUsageToKick\x18\x16 \x01(\x01:\x03\x30.9\x12(\n\x1cResourceChangeReactionPeriod\x18\x17 \x01(\x04:\x02\x31\x30\x12&\n\x18TabletKickCooldownPeriod\x18\x18 \x01(\x04:\x04\x31\x38\x30\x30\x12!\n\x16ResourceOvercommitment\x18\x19 \x01(\x01:\x01\x33\x12\x1b\n\x10\x42\x61lancerInflight\x18\x1a \x01(\x04:\x01\x31\x12u\n\x13NodeBalanceStrategy\x18\x1b \x01(\x0e\x32\x33.NKikimrConfig.THiveConfig.EHiveNodeBalanceStrategy:#HIVE_NODE_BALANCE_STRATEGY_HEAVIEST\x12\x82\x01\n\x15TabletBalanceStrategy\x18\x1c \x01(\x0e\x32\x35.NKikimrConfig.THiveConfig.EHiveTabletBalanceStrategy:,HIVE_TABLET_BALANCE_STRATEGY_WEIGHTED_RANDOM\x12\"\n\x17MinPeriodBetweenBalance\x18\x1d \x01(\x01:\x01\x31\x12%\n\x1aMaxMovementsOnAutoBalancer\x18\x1e \x01(\x04:\x01\x31\x12\"\n\x14\x43ontinueAutoBalancer\x18\x1f \x01(\x08:\x04true\x12\"\n\x15MinNodeUsageToBalance\x18  \x01(\x01:\x03\x30.3\x12%\n\x18MinPeriodBetweenReassign\x18! \x01(\x01:\x03\x33\x30\x30\x12&\n\x18TabletRestartWatchPeriod\x18\" \x01(\x01:\x04\x33\x36\x30\x30\x12$\n\x16NodeRestartWatchPeriod\x18# \x01(\x01:\x04\x33\x36\x30\x30\x12\x1f\n\x10NodeDeletePeriod\x18$ \x01(\x04:\x05\x31\x34\x34\x30\x30\x12;\n\x12\x44\x65\x66\x61ultTabletLimit\x18% \x03(\x0b\x32\x1f.NKikimrConfig.THiveTabletLimit\x12\x45\n\x17\x44\x65\x66\x61ultTabletPreference\x18& \x03(\x0b\x32$.NKikimrConfig.THiveTabletPreference\x12!\n\x16SystemTabletCategoryId\x18\' \x01(\x04:\x01\x31\x12\"\n\x14\x45nableFastTabletMove\x18( \x01(\x08:\x04true\x12\"\n\x14TabletRestartsPeriod\x18* \x01(\x04:\x04\x31\x30\x30\x30\x12 \n\x15TabletRestarsMaxCount\x18+ \x01(\x04:\x01\x32\x12!\n\x13PostponeStartPeriod\x18, \x01(\x04:\x04\x31\x30\x30\x30\x12w\n\x12NodeSelectStrategy\x18- \x01(\x0e\x32\x32.NKikimrConfig.THiveConfig.EHiveNodeSelectStrategy:\'HIVE_NODE_SELECT_STRATEGY_RANDOM_MIN_7P\x12!\n\x13\x43heckMoveExpediency\x18. \x01(\x08:\x04true\x12%\n\x16StoragePoolFreshPeriod\x18/ \x01(\x04:\x05\x36\x30\x30\x30\x30\x12.\n\x16PoolsToMonitorForUsage\x18\x30 \x01(\t:\x0eSystem,User,IC\x12H\n\x19\x42\x61lancerIgnoreTabletTypes\x18\x31 \x03(\x0e\x32%.NKikimrTabletBase.TTabletTypes.EType\"\xc3\x01\n\x1b\x45HiveStorageBalanceStrategy\x12&\n\"HIVE_STORAGE_BALANCE_STRATEGY_AUTO\x10\x00\x12&\n\"HIVE_STORAGE_BALANCE_STRATEGY_IOPS\x10\x01\x12,\n(HIVE_STORAGE_BALANCE_STRATEGY_THROUGHPUT\x10\x02\x12&\n\"HIVE_STORAGE_BALANCE_STRATEGY_SIZE\x10\x03\"\x81\x02\n\x1a\x45HiveStorageSelectStrategy\x12\x30\n,HIVE_STORAGE_SELECT_STRATEGY_WEIGHTED_RANDOM\x10\x00\x12*\n&HIVE_STORAGE_SELECT_STRATEGY_EXACT_MIN\x10\x01\x12.\n*HIVE_STORAGE_SELECT_STRATEGY_RANDOM_MIN_7P\x10\x02\x12,\n(HIVE_STORAGE_SELECT_STRATEGY_ROUND_ROBIN\x10\x03\x12\'\n#HIVE_STORAGE_SELECT_STRATEGY_RANDOM\x10\x04\"\xce\x01\n\x18\x45HiveNodeBalanceStrategy\x12\x32\n.HIVE_NODE_BALANCE_STRATEGY_OLD_WEIGHTED_RANDOM\x10\x00\x12\'\n#HIVE_NODE_BALANCE_STRATEGY_HEAVIEST\x10\x01\x12%\n!HIVE_NODE_BALANCE_STRATEGY_RANDOM\x10\x02\x12.\n*HIVE_NODE_BALANCE_STRATEGY_WEIGHTED_RANDOM\x10\x03\"\xd8\x01\n\x1a\x45HiveTabletBalanceStrategy\x12\x34\n0HIVE_TABLET_BALANCE_STRATEGY_OLD_WEIGHTED_RANDOM\x10\x00\x12)\n%HIVE_TABLET_BALANCE_STRATEGY_HEAVIEST\x10\x01\x12\'\n#HIVE_TABLET_BALANCE_STRATEGY_RANDOM\x10\x02\x12\x30\n,HIVE_TABLET_BALANCE_STRATEGY_WEIGHTED_RANDOM\x10\x03\"\xc4\x01\n\x17\x45HiveNodeSelectStrategy\x12-\n)HIVE_NODE_SELECT_STRATEGY_WEIGHTED_RANDOM\x10\x00\x12\'\n#HIVE_NODE_SELECT_STRATEGY_EXACT_MIN\x10\x01\x12+\n\'HIVE_NODE_SELECT_STRATEGY_RANDOM_MIN_7P\x10\x02\x12$\n HIVE_NODE_SELECT_STRATEGY_RANDOM\x10\x03\"\xce\x04\n\x10TDataShardConfig\x12\x1e\n\x0e\x42\x61\x63kupTaskName\x18\x01 \x01(\t:\x06\x62\x61\x63kup\x12\x1e\n\x12\x42\x61\x63kupTaskPriority\x18\x02 \x01(\r:\x02\x31\x30\x12!\n\x11\x42\x61\x63kupReadAheadLo\x18\x03 \x01(\x04:\x06\x35\x32\x34\x32\x38\x38\x12\"\n\x11\x42\x61\x63kupReadAheadHi\x18\x04 \x01(\x04:\x07\x31\x30\x34\x38\x35\x37\x36\x12#\n\x13KeepSnapshotTimeout\x18\x05 \x01(\x04:\x06\x33\x30\x30\x30\x30\x30\x12%\n\x16\x43hangesQueueItemsLimit\x18\x06 \x01(\x04:\x05\x31\x30\x30\x30\x30\x12)\n\x16\x43hangesQueueBytesLimit\x18\x07 \x01(\x04:\t131072000\x12 \n\x0fRestoreTaskName\x18\x08 \x01(\t:\x07restore\x12\x1f\n\x13RestoreTaskPriority\x18\t \x01(\r:\x02\x31\x30\x12$\n\x15\x43leanupSnapshotPeriod\x18\n \x01(\x04:\x05\x31\x35\x30\x30\x30\x12\x18\n\x0bTtlTaskName\x18\x0b \x01(\t:\x03ttl\x12\x1b\n\x0fTtlTaskPriority\x18\x0c \x01(\r:\x02\x31\x30\x12\x1e\n\x0eTtlReadAheadLo\x18\r \x01(\x04:\x06\x35\x32\x34\x32\x38\x38\x12\x1f\n\x0eTtlReadAheadHi\x18\x0e \x01(\x04:\x07\x31\x30\x34\x38\x35\x37\x36\x12,\n IdleMemCompactionIntervalSeconds\x18\x0f \x01(\x04:\x02\x36\x30\x12-\n\x1aRestoreReadBufferSizeLimit\x18\x10 \x01(\x04:\t268435456\"\xbb\x02\n\x12TSchemeShardConfig\x12 \n\x13StatsBatchTimeoutMs\x18\x01 \x01(\r:\x03\x31\x30\x30\x12\x1e\n\x11StatsMaxBatchSize\x18\x02 \x01(\r:\x03\x31\x30\x30\x12\x1d\n\x11StatsMaxExecuteMs\x18\x03 \x01(\r:\x02\x31\x30\x12W\n\x15InFlightCounterConfig\x18\x04 \x03(\x0b\x32\x38.NKikimrConfig.TSchemeShardConfig.TInFlightCounterConfig\x1ak\n\x16TInFlightCounterConfig\x12\x33\n\x04Type\x18\x01 \x01(\x0e\x32%.NKikimr.NSchemeShard.ESimpleCounters\x12\x1c\n\rInFlightLimit\x18\x02 \x01(\r:\x05\x31\x30\x30\x30\x30\"\xa8\x05\n\x11TCompactionConfig\x12`\n\x1a\x42\x61\x63kgroundCompactionConfig\x18\x01 \x01(\x0b\x32<.NKikimrConfig.TCompactionConfig.TBackgroundCompactionConfig\x12\\\n\x18\x42orrowedCompactionConfig\x18\x02 \x01(\x0b\x32:.NKikimrConfig.TCompactionConfig.TBorrowedCompactionConfig\x1a\xea\x02\n\x1bTBackgroundCompactionConfig\x12\x12\n\x07MaxRate\x18\x01 \x01(\x01:\x01\x31\x12\x18\n\rInflightLimit\x18\x02 \x01(\x04:\x01\x31\x12\x1b\n\x0eTimeoutSeconds\x18\x03 \x01(\x04:\x03\x36\x30\x30\x12!\n\x15WakeupIntervalSeconds\x18\x04 \x01(\x04:\x02\x36\x30\x12,\n\x1fMinCompactionRepeatDelaySeconds\x18\x05 \x01(\x04:\x03\x36\x30\x30\x12 \n\x15SearchHeightThreshold\x18\x06 \x01(\r:\x01\x35\x12\'\n\x13RowDeletesThreshold\x18\x07 \x01(\r:\n4294967295\x12\x1c\n\x11RowCountThreshold\x18\x08 \x01(\r:\x01\x31\x12\x1c\n\x0cRoundSeconds\x18\t \x01(\x04:\x06\x31\x37\x32\x38\x30\x30\x12(\n\x19\x43ompactSinglePartedShards\x18\n \x01(\x08:\x05\x66\x61lse\x1a\x66\n\x19TBorrowedCompactionConfig\x12\x12\n\x07MaxRate\x18\x01 \x01(\x01:\x01\x30\x12\x19\n\rInflightLimit\x18\x02 \x01(\x04:\x02\x31\x30\x12\x1a\n\x0eTimeoutSeconds\x18\x03 \x01(\x04:\x02\x31\x35\"<\n\x0eTTracingConfig\x12\x0c\n\x04Host\x18\x01 \x01(\t\x12\x0c\n\x04Port\x18\x02 \x01(\r\x12\x0e\n\x06RootCA\x18\x03 \x01(\t\"D\n\x17TFailureInjectionConfig\x12)\n\x1e\x41pproximateTerminationInterval\x18\x01 \x01(\r:\x01\x30\",\n\x0cTNamedConfig\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x0e\n\x06\x43onfig\x18\x02 \x01(\x0c\"B\n\x12TConfigItemVersion\x12\x0c\n\x04Kind\x18\x01 \x01(\r\x12\n\n\x02Id\x18\x02 \x01(\x04\x12\x12\n\nGeneration\x18\x03 \x01(\x04\"B\n\x0eTConfigVersion\x12\x30\n\x05Items\x18\x01 \x03(\x0b\x32!.NKikimrConfig.TConfigItemVersion\"\xe2\x02\n\x1fTClientCertificateAuthorization\x12g\n\x18\x44ynamicNodeAuthorization\x18\x01 \x01(\x0b\x32\x45.NKikimrConfig.TClientCertificateAuthorization.TDynamicNodeDefinition\x1a\x43\n\x0cTSubjectTerm\x12\x11\n\tShortName\x18\x01 \x01(\t\x12\x0e\n\x06Values\x18\x02 \x03(\t\x12\x10\n\x08Suffixes\x18\x03 \x03(\t\x1a\x90\x01\n\x16TDynamicNodeDefinition\x12Q\n\x0cSubjectTerms\x18\x01 \x03(\x0b\x32;.NKikimrConfig.TClientCertificateAuthorization.TSubjectTerm\x12#\n\x14\x43\x61nCheckNodeHostByCN\x18\x02 \x01(\x08:\x05\x66\x61lse\"\xab\x1b\n\nTAppConfig\x12<\n\x11\x41\x63torSystemConfig\x18\x01 \x01(\x0b\x32!.NKikimrConfig.TActorSystemConfig\x12,\n\tLogConfig\x18\x02 \x01(\x0b\x32\x19.NKikimrConfig.TLogConfig\x12\x42\n\x11NameserviceConfig\x18\x03 \x01(\x0b\x32\'.NKikimrConfig.TStaticNameserviceConfig\x12>\n\x12InterconnectConfig\x18\x04 \x01(\x0b\x32\".NKikimrConfig.TInterconnectConfig\x12\x34\n\rDomainsConfig\x18\x05 \x01(\x0b\x32\x1d.NKikimrConfig.TDomainsConfig\x12<\n\x11\x42lobStorageConfig\x18\x06 \x01(\x0b\x32!.NKikimrConfig.TBlobStorageConfig\x12\x42\n\x14\x43hannelProfileConfig\x18\x07 \x01(\x0b\x32$.NKikimrConfig.TChannelProfileConfig\x12\x32\n\x0f\x42ootstrapConfig\x18\x08 \x01(\x0b\x32\x19.NKikimrConfig.TBootstrap\x12:\n\x10MonitoringConfig\x18\n \x01(\x0b\x32 .NKikimrConfig.TMonitoringConfig\x12@\n\x13RestartsCountConfig\x18\x0b \x01(\x0b\x32#.NKikimrConfig.TRestartsCountConfig\x12:\n\x10MessageBusConfig\x18\x0c \x01(\x0b\x32 .NKikimrConfig.TMessageBusConfig\x12\x34\n\rTabletsConfig\x18\r \x01(\x0b\x32\x1d.NKikimrConfig.TTabletsConfig\x12\x37\n\x0bVDiskConfig\x18\x0e \x01(\x0b\x32\".NKikimrBlobStorage.TAllVDiskKinds\x12=\n\x10\x44riveModelConfig\x18\x1f \x01(\x0b\x32#.NKikimrBlobStorage.TDriveModelList\x12;\n\x0eIncrHugeConfig\x18\x12 \x01(\x0b\x32#.NKikimrBlobStorage.TIncrHugeConfig\x12\x0f\n\x07UDFsDir\x18\x0f \x01(\t\x12\x11\n\tUDFsPaths\x18\x10 \x03(\t\x12,\n\tKQPConfig\x18\x11 \x01(\x0b\x32\x19.NKikimrConfig.TKQPConfig\x12\x38\n\x0fMemoryLogConfig\x18\x13 \x01(\x0b\x32\x1f.NKikimrConfig.TMemoryLogConfig\x12.\n\nGRpcConfig\x18\x14 \x01(\x0b\x32\x1a.NKikimrConfig.TGRpcConfig\x12J\n\x18\x44ynamicNameserviceConfig\x18\x16 \x01(\x0b\x32(.NKikimrConfig.TDynamicNameserviceConfig\x12<\n\x11\x44ynamicNodeConfig\x18\x18 \x01(\x0b\x32!.NKikimrConfig.TDynamicNodeConfig\x12)\n\tCmsConfig\x18\x19 \x01(\x0b\x32\x16.NKikimrCms.TCmsConfig\x12\x32\n\x0c\x46\x65\x61tureFlags\x18\x1a \x01(\x0b\x32\x1c.NKikimrConfig.TFeatureFlags\x12,\n\tSqsConfig\x18\x1b \x01(\x0b\x32\x19.NKikimrConfig.TSqsConfig\x12&\n\x08PQConfig\x18\x1c \x01(\x0b\x32\x14.NKikimrPQ.TPQConfig\x12>\n\x10TenantPoolConfig\x18\x1d \x01(\x0b\x32$.NKikimrTenantPool.TTenantPoolConfig\x12-\n\nAuthConfig\x18\x1e \x01(\x0b\x32\x19.NKikimrProto.TAuthConfig\x12@\n\x16TenantSlotBrokerConfig\x18  \x01(\x0b\x32 .NKikimrTenantSlotBroker.TConfig\x12H\n\x17\x43onfigsDispatcherConfig\x18! \x01(\x0b\x32\'.NKikimrConfig.TConfigsDispatcherConfig\x12@\n\x13TableProfilesConfig\x18\" \x01(\x0b\x32#.NKikimrConfig.TTableProfilesConfig\x12+\n\tKeyConfig\x18# \x01(\x0b\x32\x18.NKikimrProto.TKeyConfig\x12\x30\n\x0ePDiskKeyConfig\x18\x33 \x01(\x0b\x32\x18.NKikimrProto.TKeyConfig\x12\x34\n\x10NodeBrokerConfig\x18$ \x01(\x0b\x32\x1a.NKikimrNodeBroker.TConfig\x12>\n\x12TableServiceConfig\x18% \x01(\x0b\x32\".NKikimrConfig.TTableServiceConfig\x12\x41\n\x11SharedCacheConfig\x18& \x01(\x0b\x32&.NKikimrSharedCache.TSharedCacheConfig\x12H\n\x17ImmediateControlsConfig\x18\' \x01(\x0b\x32\'.NKikimrConfig.TImmediateControlsConfig\x12\x38\n\x0f\x41llocatorConfig\x18( \x01(\x0b\x32\x1f.NKikimrConfig.TAllocatorConfig\x12\x46\n\x18PQClusterDiscoveryConfig\x18) \x01(\x0b\x32$.NKikimrPQ.TPQClusterDiscoveryConfig\x12G\n\x13NetClassifierConfig\x18* \x01(\x0b\x32*.NKikimrNetClassifier.TNetClassifierConfig\x12\x61\n NetClassifierDistributableConfig\x18+ \x01(\x0b\x32\x37.NKikimrNetClassifier.TNetClassifierDistributableConfig\x12J\n\x14ResourceBrokerConfig\x18, \x01(\x0b\x32,.NKikimrResourceBroker.TResourceBrokerConfig\x12\x36\n\x0eMeteringConfig\x18- \x01(\x0b\x32\x1e.NKikimrConfig.TMeteringConfig\x12.\n\nHiveConfig\x18. \x01(\x0b\x32\x1a.NKikimrConfig.THiveConfig\x12\x38\n\x0f\x44\x61taShardConfig\x18\x31 \x01(\x0b\x32\x1f.NKikimrConfig.TDataShardConfig\x12\x32\n\x14\x46\x65\x64\x65ratedQueryConfig\x18: \x01(\x0b\x32\x14.NYq.NConfig.TConfig\x12:\n\x10\x43ompactionConfig\x18\x34 \x01(\x0b\x32 .NKikimrConfig.TCompactionConfig\x12\x38\n\x0fHttpProxyConfig\x18\x35 \x01(\x0b\x32\x1f.NKikimrConfig.THttpProxyConfig\x12<\n\x11SchemeShardConfig\x18\x36 \x01(\x0b\x32!.NKikimrConfig.TSchemeShardConfig\x12\x34\n\rTracingConfig\x18\x37 \x01(\x0b\x32\x1d.NKikimrConfig.TTracingConfig\x12\x46\n\x16\x46\x61ilureInjectionConfig\x18\x38 \x01(\x0b\x32&.NKikimrConfig.TFailureInjectionConfig\x12\x39\n\x10PublicHttpConfig\x18\x39 \x01(\x0b\x32\x1f.NKikimrConfig.THttpProxyConfig\x12\x46\n\x16MetadataProviderConfig\x18; \x01(\x0b\x32&.NKikimrConfig.TMetadataProviderConfig\x12\x44\n\x15\x42\x61\x63kgroundTasksConfig\x18< \x01(\x0b\x32%.NKikimrConfig.TBackgroundTasksConfig\x12\x30\n\x0b\x41uditConfig\x18= \x01(\x0b\x32\x1b.NKikimrConfig.TAuditConfig\x12V\n\x1e\x43lientCertificateAuthorization\x18> \x01(\x0b\x32..NKikimrConfig.TClientCertificateAuthorization\x12/\n\x11YandexQueryConfig\x18\x32 \x01(\x0b\x32\x14.NYq.NConfig.TConfig\x12\x31\n\x0cNamedConfigs\x18\x64 \x03(\x0b\x32\x1b.NKikimrConfig.TNamedConfig\x12\x19\n\x11\x43lusterYamlConfig\x18\x65 \x01(\t\x12.\n\x07Version\x18\x66 \x01(\x0b\x32\x1d.NKikimrConfig.TConfigVersion:`\n\x0e\x43ontrolOptions\x12\x1d.google.protobuf.FieldOptions\x18\xc9\xdc\x03 \x01(\x0b\x32\'.NKikimrConfig.TImmediateControlOptionsB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.config_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:
  google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(ControlOptions)

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TSTATICNAMESERVICECONFIG_TNODE.fields_by_name['WalleLocation']._options = None
  _TSTATICNAMESERVICECONFIG_TNODE.fields_by_name['WalleLocation']._serialized_options = b'\030\001'
  _TIMMEDIATECONTROLSCONFIG_TDATASHARDCONTROLS_TEXECUTIONPROFILEOPTIONS.fields_by_name['LogThresholdMs']._options = None
  _TIMMEDIATECONTROLSCONFIG_TDATASHARDCONTROLS_TEXECUTIONPROFILEOPTIONS.fields_by_name['LogThresholdMs']._serialized_options = b'\312\344\0354\n)Log execution profile for slow operations\020\000\030\200\270\231) \000'
  _TIMMEDIATECONTROLSCONFIG_TDATASHARDCONTROLS_TEXECUTIONPROFILEOPTIONS.fields_by_name['BufferThresholdMs']._options = None
  _TIMMEDIATECONTROLSCONFIG_TDATASHARDCONTROLS_TEXECUTIONPROFILEOPTIONS.fields_by_name['BufferThresholdMs']._serialized_options = b'\312\344\0356\n+Store execution profile for slow operations\020\000\030\200\270\231) \000'
  _TIMMEDIATECONTROLSCONFIG_TDATASHARDCONTROLS_TEXECUTIONPROFILEOPTIONS.fields_by_name['BufferSize']._options = None
  _TIMMEDIATECONTROLSCONFIG_TDATASHARDCONTROLS_TEXECUTIONPROFILEOPTIONS.fields_by_name['BufferSize']._serialized_options = b'\312\344\035,\n#Slow operation profiles buffer size\020\000\030\350\007 d'
  _TIMMEDIATECONTROLSCONFIG_TDATASHARDCONTROLS.fields_by_name['MaxTxInFly']._options = None
  _TIMMEDIATECONTROLSCONFIG_TDATASHARDCONTROLS.fields_by_name['MaxTxInFly']._serialized_options = b'\312\344\0351\n&Maximum tx queue size for single shard\020\000\030\240\215\006 \230u'
  _TIMMEDIATECONTROLSCONFIG_TDATASHARDCONTROLS.fields_by_name['DisableByKeyFilter']._options = None
  _TIMMEDIATECONTROLSCONFIG_TDATASHARDCONTROLS.fields_by_name['DisableByKeyFilter']._serialized_options = b'\312\344\0351\n)Disable bloom filter usage on row selects\020\000\030\001 \000'
  _TIMMEDIATECONTROLSCONFIG_TDATASHARDCONTROLS.fields_by_name['MaxTxLagMilliseconds']._options = None
  _TIMMEDIATECONTROLSCONFIG_TDATASHARDCONTROLS.fields_by_name['MaxTxLagMilliseconds']._serialized_options = b'\312\344\035J\n<Max lag in tx plan execution before shard becomes overloaded\020\000\030\200\220\373\323\t \340\247\022'
  _TIMMEDIATECONTROLSCONFIG_TDATASHARDCONTROLS.fields_by_name['CanCancelROWithReadSets']._options = None
  _TIMMEDIATECONTROLSCONFIG_TDATASHARDCONTROLS.fields_by_name['CanCancelROWithReadSets']._serialized_options = b'\312\344\035>\n6Allow to cancel RO tx with output read sets by timeout\020\000\030\001 \000'
  _TIMMEDIATECONTROLSCONFIG_TDATASHARDCONTROLS.fields_by_name['BackupReadAheadLo']._options = None
  _TIMMEDIATECONTROLSCONFIG_TDATASHARDCONTROLS.fields_by_name['BackupReadAheadLo']._serialized_options = b'\312\344\0358\n-Override for backup readahead (low watermark)\020\000\030\200\200\200  \000'
  _TIMMEDIATECONTROLSCONFIG_TDATASHARDCONTROLS.fields_by_name['BackupReadAheadHi']._options = None
  _TIMMEDIATECONTROLSCONFIG_TDATASHARDCONTROLS.fields_by_name['BackupReadAheadHi']._serialized_options = b'\312\344\0359\n.Override for backup readahead (high watermark)\020\000\030\200\200\200@ \000'
  _TIMMEDIATECONTROLSCONFIG_TDATASHARDCONTROLS.fields_by_name['PrioritizedMvccSnapshotReads']._options = None
  _TIMMEDIATECONTROLSCONFIG_TDATASHARDCONTROLS.fields_by_name['PrioritizedMvccSnapshotReads']._serialized_options = b'\312\344\035E\n=Enables prioritized mvcc snapshot reads over immediate writes\020\000\030\001 \001'
  _TIMMEDIATECONTROLSCONFIG_TDATASHARDCONTROLS.fields_by_name['UnprotectedMvccSnapshotReads']._options = None
  _TIMMEDIATECONTROLSCONFIG_TDATASHARDCONTROLS.fields_by_name['UnprotectedMvccSnapshotReads']._serialized_options = b'\312\344\035@\n8Enables unprotected (fully readonly) mvcc snapshot reads\020\000\030\001 \001'
  _TIMMEDIATECONTROLSCONFIG_TDATASHARDCONTROLS.fields_by_name['EnableLeaderLeases']._options = None
  _TIMMEDIATECONTROLSCONFIG_TDATASHARDCONTROLS.fields_by_name['EnableLeaderLeases']._serialized_options = b'\312\344\035>\n6Enables leader leases for processing read-only queries\020\000\030\001 \001'
  _TIMMEDIATECONTROLSCONFIG_TDATASHARDCONTROLS.fields_by_name['MinLeaderLeaseDurationUs']._options = None
  _TIMMEDIATECONTROLSCONFIG_TDATASHARDCONTROLS.fields_by_name['MinLeaderLeaseDurationUs']._serialized_options = b'\312\344\035?\n1The minimum leader lease duration in microseconds\020\350\007\030\300\226\261\002 \220\241\017'
  _TIMMEDIATECONTROLSCONFIG_TDATASHARDCONTROLS.fields_by_name['TtlReadAheadLo']._options = None
  _TIMMEDIATECONTROLSCONFIG_TDATASHARDCONTROLS.fields_by_name['TtlReadAheadLo']._serialized_options = b'\312\344\0355\n*Override for ttl readahead (low watermark)\020\000\030\200\200\200  \000'
  _TIMMEDIATECONTROLSCONFIG_TDATASHARDCONTROLS.fields_by_name['TtlReadAheadHi']._options = None
  _TIMMEDIATECONTROLSCONFIG_TDATASHARDCONTROLS.fields_by_name['TtlReadAheadHi']._serialized_options = b'\312\344\0356\n+Override for ttl readahead (high watermark)\020\000\030\200\200\200@ \000'
  _TIMMEDIATECONTROLSCONFIG_TDATASHARDCONTROLS.fields_by_name['EnableLockedWrites']._options = None
  _TIMMEDIATECONTROLSCONFIG_TDATASHARDCONTROLS.fields_by_name['EnableLockedWrites']._serialized_options = b'\312\344\0355\n-Enables experimental persistent locked writes\020\000\030\001 \000'
  _TIMMEDIATECONTROLSCONFIG_TDATASHARDCONTROLS.fields_by_name['MaxLockedWritesPerKey']._options = None
  _TIMMEDIATECONTROLSCONFIG_TDATASHARDCONTROLS.fields_by_name['MaxLockedWritesPerKey']._serialized_options = b'\312\344\035>\n3Maximum number of uncommitted locked writes per key\020\000\030\300\204= \350\007'
  _TIMMEDIATECONTROLSCONFIG_TTXLIMITCONTROLS.fields_by_name['PerRequestDataSizeLimit']._options = None
  _TIMMEDIATECONTROLSCONFIG_TTXLIMITCONTROLS.fields_by_name['PerRequestDataSizeLimit']._serialized_options = b'\312\344\0359\n&Maximum read data size per transaction\020\000\030\200\200\300\250\312\232: \200\200\200\200\310\001'
  _TIMMEDIATECONTROLSCONFIG_TTXLIMITCONTROLS.fields_by_name['PerShardReadSizeLimit']._options = None
  _TIMMEDIATECONTROLSCONFIG_TTXLIMITCONTROLS.fields_by_name['PerShardReadSizeLimit']._serialized_options = b'\312\344\035A\n0Maximum read data size per transaction per shard\020\000\030\200\200\200\200\220\003 \200\200\200\200\024'
  _TIMMEDIATECONTROLSCONFIG_TTXLIMITCONTROLS.fields_by_name['PerShardIncomingReadSetSizeLimit']._options = None
  _TIMMEDIATECONTROLSCONFIG_TTXLIMITCONTROLS.fields_by_name['PerShardIncomingReadSetSizeLimit']._serialized_options = b'\312\344\035E\n6Maximum input read sets size per transaction per shard\020\000\030\200\200\200\200\024 \200\200\200d'
  _TIMMEDIATECONTROLSCONFIG_TTXLIMITCONTROLS.fields_by_name['DefaultTimeoutMs']._options = None
  _TIMMEDIATECONTROLSCONFIG_TTXLIMITCONTROLS.fields_by_name['DefaultTimeoutMs']._serialized_options = b'\312\344\0357\n*Default execution timeout for transactions\020\000\030\200\335\333\001 \340\324\003'
  _TIMMEDIATECONTROLSCONFIG_TCOORDINATORCONTROLS.fields_by_name['EnableLeaderLeases']._options = None
  _TIMMEDIATECONTROLSCONFIG_TCOORDINATORCONTROLS.fields_by_name['EnableLeaderLeases']._serialized_options = b'\312\344\035>\n6Enables leader leases for processing read-only queries\020\000\030\001 \001'
  _TIMMEDIATECONTROLSCONFIG_TCOORDINATORCONTROLS.fields_by_name['MinLeaderLeaseDurationUs']._options = None
  _TIMMEDIATECONTROLSCONFIG_TCOORDINATORCONTROLS.fields_by_name['MinLeaderLeaseDurationUs']._serialized_options = b'\312\344\035?\n1The minimum leader lease duration in microseconds\020\350\007\030\300\226\261\002 \220\241\017'
  _TIMMEDIATECONTROLSCONFIG_TSCHEMESHARDCONTROLS.fields_by_name['ForceShardSplitDataSize']._options = None
  _TIMMEDIATECONTROLSCONFIG_TSCHEMESHARDCONTROLS.fields_by_name['ForceShardSplitDataSize']._serialized_options = b'\312\344\035^\nKForces shards to split when reaching the given data size (2 GiB by default)\020\200\200\200\005\030\200\200\200\200@ \200\200\200\200\010'
  _TIMMEDIATECONTROLSCONFIG_TSCHEMESHARDCONTROLS.fields_by_name['DisableForceShardSplit']._options = None
  _TIMMEDIATECONTROLSCONFIG_TSCHEMESHARDCONTROLS.fields_by_name['DisableForceShardSplit']._serialized_options = b'\312\344\035<\n4Disables forced shard splits, for special cases only\020\000\030\001 \000'
  _TAFFINITY._serialized_start=1091
  _TAFFINITY._serialized_end=1154
  _TACTORSYSTEMCONFIG._serialized_start=1157
  _TACTORSYSTEMCONFIG._serialized_end=2649
  _TACTORSYSTEMCONFIG_TEXECUTOR._serialized_start=1629
  _TACTORSYSTEMCONFIG_TEXECUTOR._serialized_end=2135
  _TACTORSYSTEMCONFIG_TEXECUTOR_ETYPE._serialized_start=2097
  _TACTORSYSTEMCONFIG_TEXECUTOR_ETYPE._serialized_end=2135
  _TACTORSYSTEMCONFIG_TSCHEDULER._serialized_start=2138
  _TACTORSYSTEMCONFIG_TSCHEDULER._serialized_end=2291
  _TACTORSYSTEMCONFIG_TSERVICEEXECUTOR._serialized_start=2293
  _TACTORSYSTEMCONFIG_TSERVICEEXECUTOR._serialized_end=2352
  _TACTORSYSTEMCONFIG_TUNITEDWORKERS._serialized_start=2355
  _TACTORSYSTEMCONFIG_TUNITEDWORKERS._serialized_end=2649
  _TSTATICNAMESERVICECONFIG._serialized_start=2652
  _TSTATICNAMESERVICECONFIG._serialized_end=3296
  _TSTATICNAMESERVICECONFIG_TENDPOINT._serialized_start=2884
  _TSTATICNAMESERVICECONFIG_TENDPOINT._serialized_end=2926
  _TSTATICNAMESERVICECONFIG_TNODE._serialized_start=2929
  _TSTATICNAMESERVICECONFIG_TNODE._serialized_end=3209
  _TSTATICNAMESERVICECONFIG_ENAMESERVICETYPE._serialized_start=3211
  _TSTATICNAMESERVICECONFIG_ENAMESERVICETYPE._serialized_end=3296
  _TDYNAMICNAMESERVICECONFIG._serialized_start=3298
  _TDYNAMICNAMESERVICECONFIG._serialized_end=3425
  _TDOMAINSCONFIG._serialized_start=3428
  _TDOMAINSCONFIG._serialized_end=5530
  _TDOMAINSCONFIG_TSTATESTORAGE._serialized_start=3891
  _TDOMAINSCONFIG_TSTATESTORAGE._serialized_end=4248
  _TDOMAINSCONFIG_TSTATESTORAGE_TRING._serialized_start=4048
  _TDOMAINSCONFIG_TSTATESTORAGE_TRING._serialized_end=4248
  _TDOMAINSCONFIG_TSTORAGEPOOLTYPE._serialized_start=4250
  _TDOMAINSCONFIG_TSTORAGEPOOLTYPE._serialized_end=4342
  _TDOMAINSCONFIG_TDOMAIN._serialized_start=4345
  _TDOMAINSCONFIG_TDOMAIN._serialized_end=4885
  _TDOMAINSCONFIG_TDOMAIN_TTXLIMITS._serialized_start=4768
  _TDOMAINSCONFIG_TDOMAIN_TTXLIMITS._serialized_end=4885
  _TDOMAINSCONFIG_THIVECONFIG._serialized_start=4887
  _TDOMAINSCONFIG_THIVECONFIG._serialized_end=4931
  _TDOMAINSCONFIG_TEXECLEVEL._serialized_start=4933
  _TDOMAINSCONFIG_TEXECLEVEL._serialized_end=4945
  _TDOMAINSCONFIG_TNAMEDCOMPACTIONPOLICY._serialized_start=4947
  _TDOMAINSCONFIG_TNAMEDCOMPACTIONPOLICY._serialized_end=5037
  _TDOMAINSCONFIG_TSECURITYCONFIG._serialized_start=5040
  _TDOMAINSCONFIG_TSECURITYCONFIG._serialized_end=5530
  _TDOMAINSCONFIG_TSECURITYCONFIG_TUSER._serialized_start=5450
  _TDOMAINSCONFIG_TSECURITYCONFIG_TUSER._serialized_end=5489
  _TDOMAINSCONFIG_TSECURITYCONFIG_TGROUP._serialized_start=5491
  _TDOMAINSCONFIG_TSECURITYCONFIG_TGROUP._serialized_end=5530
  _TBLOBSTORAGECONFIG._serialized_start=5533
  _TBLOBSTORAGECONFIG._serialized_end=5736
  _TBLOBSTORAGEFORMATCONFIG._serialized_start=5739
  _TBLOBSTORAGEFORMATCONFIG._serialized_end=6057
  _TBLOBSTORAGEFORMATCONFIG_TDRIVE._serialized_start=5831
  _TBLOBSTORAGEFORMATCONFIG_TDRIVE._serialized_end=6057
  _TUACLIENTCONFIG._serialized_start=6060
  _TUACLIENTCONFIG._serialized_end=6302
  _TLOGCONFIG._serialized_start=6305
  _TLOGCONFIG._serialized_end=6870
  _TLOGCONFIG_TENTRY._serialized_start=6783
  _TLOGCONFIG_TENTRY._serialized_end=6870
  _TCOMPILESERVICECONFIG._serialized_start=6872
  _TCOMPILESERVICECONFIG._serialized_end=6926
  _TBOOTSTRAP._serialized_start=6929
  _TBOOTSTRAP._serialized_end=8144
  _TBOOTSTRAP_TTABLET._serialized_start=7474
  _TBOOTSTRAP_TTABLET._serialized_end=7710
  _TBOOTSTRAP_ETABLETTYPE._serialized_start=7713
  _TBOOTSTRAP_ETABLETTYPE._serialized_end=8144
  _TINTERCONNECTCONFIG._serialized_start=8147
  _TINTERCONNECTCONFIG._serialized_end=9992
  _TINTERCONNECTCONFIG_TCHANNEL._serialized_start=9802
  _TINTERCONNECTCONFIG_TCHANNEL._serialized_end=9858
  _TINTERCONNECTCONFIG_EMERGEMODE._serialized_start=9860
  _TINTERCONNECTCONFIG_EMERGEMODE._serialized_end=9931
  _TINTERCONNECTCONFIG_EENCRYPTIONMODE._serialized_start=9933
  _TINTERCONNECTCONFIG_EENCRYPTIONMODE._serialized_end=9992
  _TCHANNELPROFILECONFIG._serialized_start=9995
  _TCHANNELPROFILECONFIG._serialized_end=10347
  _TCHANNELPROFILECONFIG_TPROFILE._serialized_start=10085
  _TCHANNELPROFILECONFIG_TPROFILE._serialized_end=10347
  _TCHANNELPROFILECONFIG_TPROFILE_TCHANNEL._serialized_start=10190
  _TCHANNELPROFILECONFIG_TPROFILE_TCHANNEL._serialized_end=10347
  _TMONITORINGCONFIG._serialized_start=10350
  _TMONITORINGCONFIG._serialized_end=11423
  _TMONITORINGCONFIG_TDATABASELABELS._serialized_start=10940
  _TMONITORINGCONFIG_TDATABASELABELS._serialized_end=11234
  _TMONITORINGCONFIG_TDATABASEATTRIBUTELABELS._serialized_start=11237
  _TMONITORINGCONFIG_TDATABASEATTRIBUTELABELS._serialized_end=11423
  _TMONITORINGCONFIG_TDATABASEATTRIBUTELABELS_TATTRIBUTEGROUP._serialized_start=11388
  _TMONITORINGCONFIG_TDATABASEATTRIBUTELABELS_TATTRIBUTEGROUP._serialized_end=11423
  _TRESTARTSCOUNTCONFIG._serialized_start=11425
  _TRESTARTSCOUNTCONFIG._serialized_end=11476
  _TMESSAGEBUSCONFIG._serialized_start=11479
  _TMESSAGEBUSCONFIG._serialized_end=12639
  _TMESSAGEBUSCONFIG_TBUSQUEUECONFIG._serialized_start=11851
  _TMESSAGEBUSCONFIG_TBUSQUEUECONFIG._serialized_end=11905
  _TMESSAGEBUSCONFIG_TBUSSESSIONCONFIG._serialized_start=11908
  _TMESSAGEBUSCONFIG_TBUSSESSIONCONFIG._serialized_end=12639
  _TTABLETSCONFIG._serialized_start=12642
  _TTABLETSCONFIG._serialized_end=12847
  _TTABLETSCONFIG_TTABLET._serialized_start=12716
  _TTABLETSCONFIG_TTABLET._serialized_end=12847
  _TKQPCONFIG._serialized_start=12849
  _TKQPCONFIG._serialized_end=12926
  _TINTERNALREQUESTCONFIG._serialized_start=12928
  _TINTERNALREQUESTCONFIG._serialized_end=13026
  _TMETADATAPROVIDERCONFIG._serialized_start=13029
  _TMETADATAPROVIDERCONFIG._serialized_end=13187
  _TBACKGROUNDTASKSCONFIG._serialized_start=13190
  _TBACKGROUNDTASKSCONFIG._serialized_end=13447
  _TMEMORYLOGCONFIG._serialized_start=13449
  _TMEMORYLOGCONFIG._serialized_end=13512
  _TGRPCCONFIG._serialized_start=13515
  _TGRPCCONFIG._serialized_end=14459
  _TDYNAMICNODECONFIG._serialized_start=14462
  _TDYNAMICNODECONFIG._serialized_end=14642
  _TFEATUREFLAGS._serialized_start=14645
  _TFEATUREFLAGS._serialized_end=18288
  _TFEATUREFLAGS_TRIBOOL._serialized_start=18211
  _TFEATUREFLAGS_TRIBOOL._serialized_end=18264
  _THTTPPROXYCONFIG._serialized_start=18291
  _THTTPPROXYCONFIG._serialized_end=18510
  _TSQSCONFIG._serialized_start=18513
  _TSQSCONFIG._serialized_end=22950
  _TSQSCONFIG_TBATCHINGPOLICY._serialized_start=21500
  _TSQSCONFIG_TBATCHINGPOLICY._serialized_end=21583
  _TSQSCONFIG_TQUOTINGCONFIG._serialized_start=21586
  _TSQSCONFIG_TQUOTINGCONFIG._serialized_end=22417
  _TSQSCONFIG_TQUOTINGCONFIG_TDEFAULTACTIONSRATES._serialized_start=21839
  _TSQSCONFIG_TQUOTINGCONFIG_TDEFAULTACTIONSRATES._serialized_end=22204
  _TSQSCONFIG_TQUOTINGCONFIG_TLOCALRATELIMITERCONFIG._serialized_start=22206
  _TSQSCONFIG_TQUOTINGCONFIG_TLOCALRATELIMITERCONFIG._serialized_end=22309
  _TSQSCONFIG_TQUOTINGCONFIG_TKESUSQUOTERCONFIG._serialized_start=22311
  _TSQSCONFIG_TQUOTINGCONFIG_TKESUSQUOTERCONFIG._serialized_end=22417
  _TSQSCONFIG_TACCOUNTSETTINGSDEFAULTS._serialized_start=22419
  _TSQSCONFIG_TACCOUNTSETTINGSDEFAULTS._serialized_end=22473
  _TSQSCONFIG_TYCSEARCHEVENTSCONFIG._serialized_start=22476
  _TSQSCONFIG_TYCSEARCHEVENTSCONFIG._serialized_end=22700
  _TSQSCONFIG_TOAUTHTOKENCONFIG._serialized_start=22702
  _TSQSCONFIG_TOAUTHTOKENCONFIG._serialized_end=22740
  _TSQSCONFIG_TJWTCONFIG._serialized_start=22742
  _TSQSCONFIG_TJWTCONFIG._serialized_end=22792
  _TSQSCONFIG_TYDBAUTHCONFIG._serialized_start=22795
  _TSQSCONFIG_TYDBAUTHCONFIG._serialized_end=22950
  _TCONFIGSDISPATCHERCONFIG._serialized_start=22952
  _TCONFIGSDISPATCHERCONFIG._serialized_end=22978
  _TCOMPACTIONPOLICY._serialized_start=22980
  _TCOMPACTIONPOLICY._serialized_end=23075
  _TEXECUTIONPOLICY._serialized_start=23078
  _TEXECUTIONPOLICY._serialized_end=23370
  _TPARTITIONINGPOLICY._serialized_start=23373
  _TPARTITIONINGPOLICY._serialized_end=23527
  _TSTORAGEPOLICY._serialized_start=23529
  _TSTORAGEPOLICY._serialized_end=23620
  _TREPLICATIONPOLICY._serialized_start=23622
  _TREPLICATIONPOLICY._serialized_end=23742
  _TCACHINGPOLICY._serialized_start=23744
  _TCACHINGPOLICY._serialized_end=23801
  _TTABLEPROFILE._serialized_start=23804
  _TTABLEPROFILE._serialized_end=23985
  _TTABLEPROFILESCONFIG._serialized_start=23988
  _TTABLEPROFILESCONFIG._serialized_end=24427
  _TTABLESERVICECONFIG._serialized_start=24430
  _TTABLESERVICECONFIG._serialized_end=28414
  _TTABLESERVICECONFIG_TSHARDSSCANNINGPOLICY._serialized_start=25440
  _TTABLESERVICECONFIG_TSHARDSSCANNINGPOLICY._serialized_end=25634
  _TTABLESERVICECONFIG_TRESOURCEMANAGER._serialized_start=25637
  _TTABLESERVICECONFIG_TRESOURCEMANAGER._serialized_end=26197
  _TTABLESERVICECONFIG_TSPILLINGSERVICECONFIG._serialized_start=26200
  _TTABLESERVICECONFIG_TSPILLINGSERVICECONFIG._serialized_end=26701
  _TTABLESERVICECONFIG_TSPILLINGSERVICECONFIG_TLOCALFILECONFIG._serialized_start=26328
  _TTABLESERVICECONFIG_TSPILLINGSERVICECONFIG_TLOCALFILECONFIG._serialized_end=26701
  _TTABLESERVICECONFIG_TSPILLINGSERVICECONFIG_TLOCALFILECONFIG_TIOTHREADPOOLCONFIG._serialized_start=26630
  _TTABLESERVICECONFIG_TSPILLINGSERVICECONFIG_TLOCALFILECONFIG_TIOTHREADPOOLCONFIG._serialized_end=26701
  _TTABLESERVICECONFIG_TQUERYPHASELIMITS._serialized_start=26704
  _TTABLESERVICECONFIG_TQUERYPHASELIMITS._serialized_end=26849
  _TTABLESERVICECONFIG_TQUERYLIMITS._serialized_start=26852
  _TTABLESERVICECONFIG_TQUERYLIMITS._serialized_end=27076
  _TTABLESERVICECONFIG_TSHUTDOWNSETTINGS._serialized_start=27078
  _TTABLESERVICECONFIG_TSHUTDOWNSETTINGS._serialized_end=27190
  _TTABLESERVICECONFIG_TSESSIONBALANCERSETTINGS._serialized_start=27193
  _TTABLESERVICECONFIG_TSESSIONBALANCERSETTINGS._serialized_end=28104
  _TTABLESERVICECONFIG_TSESSIONBALANCERSETTINGS_EENABLETIER._serialized_start=27908
  _TTABLESERVICECONFIG_TSESSIONBALANCERSETTINGS_EENABLETIER._serialized_end=28010
  _TTABLESERVICECONFIG_TSESSIONBALANCERSETTINGS_EBALANCINGSTRATEGY._serialized_start=28012
  _TTABLESERVICECONFIG_TSESSIONBALANCERSETTINGS_EBALANCINGSTRATEGY._serialized_end=28104
  _TTABLESERVICECONFIG_TQUERYREPLAYCONFIG._serialized_start=28107
  _TTABLESERVICECONFIG_TQUERYREPLAYCONFIG._serialized_end=28366
  _TIMMEDIATECONTROLOPTIONS._serialized_start=28416
  _TIMMEDIATECONTROLOPTIONS._serialized_end=28521
  _TIMMEDIATECONTROLSCONFIG._serialized_start=28524
  _TIMMEDIATECONTROLSCONFIG._serialized_end=31526
  _TIMMEDIATECONTROLSCONFIG_TDATASHARDCONTROLS._serialized_start=28905
  _TIMMEDIATECONTROLSCONFIG_TDATASHARDCONTROLS._serialized_end=30622
  _TIMMEDIATECONTROLSCONFIG_TDATASHARDCONTROLS_TEXECUTIONPROFILEOPTIONS._serialized_start=30357
  _TIMMEDIATECONTROLSCONFIG_TDATASHARDCONTROLS_TEXECUTIONPROFILEOPTIONS._serialized_end=30622
  _TIMMEDIATECONTROLSCONFIG_TTXLIMITCONTROLS._serialized_start=30625
  _TIMMEDIATECONTROLSCONFIG_TTXLIMITCONTROLS._serialized_end=31045
  _TIMMEDIATECONTROLSCONFIG_TCOORDINATORCONTROLS._serialized_start=31048
  _TIMMEDIATECONTROLSCONFIG_TCOORDINATORCONTROLS._serialized_end=31269
  _TIMMEDIATECONTROLSCONFIG_TSCHEMESHARDCONTROLS._serialized_start=31272
  _TIMMEDIATECONTROLSCONFIG_TSCHEMESHARDCONTROLS._serialized_end=31526
  _TMETERINGCONFIG._serialized_start=31528
  _TMETERINGCONFIG._serialized_end=31597
  _TAUDITCONFIG._serialized_start=31600
  _TAUDITCONFIG._serialized_end=31778
  _TAUDITCONFIG_EFORMAT._serialized_start=31750
  _TAUDITCONFIG_EFORMAT._serialized_end=31778
  _THIVETABLETLIMIT._serialized_start=31780
  _THIVETABLETLIMIT._serialized_end=31869
  _THIVETABLETPREFERENCE._serialized_start=31872
  _THIVETABLETPREFERENCE._serialized_end=32016
  _THIVECONFIG._serialized_start=32019
  _THIVECONFIG._serialized_end=35350
  _THIVECONFIG_EHIVESTORAGEBALANCESTRATEGY._serialized_start=34268
  _THIVECONFIG_EHIVESTORAGEBALANCESTRATEGY._serialized_end=34463
  _THIVECONFIG_EHIVESTORAGESELECTSTRATEGY._serialized_start=34466
  _THIVECONFIG_EHIVESTORAGESELECTSTRATEGY._serialized_end=34723
  _THIVECONFIG_EHIVENODEBALANCESTRATEGY._serialized_start=34726
  _THIVECONFIG_EHIVENODEBALANCESTRATEGY._serialized_end=34932
  _THIVECONFIG_EHIVETABLETBALANCESTRATEGY._serialized_start=34935
  _THIVECONFIG_EHIVETABLETBALANCESTRATEGY._serialized_end=35151
  _THIVECONFIG_EHIVENODESELECTSTRATEGY._serialized_start=35154
  _THIVECONFIG_EHIVENODESELECTSTRATEGY._serialized_end=35350
  _TDATASHARDCONFIG._serialized_start=35353
  _TDATASHARDCONFIG._serialized_end=35943
  _TSCHEMESHARDCONFIG._serialized_start=35946
  _TSCHEMESHARDCONFIG._serialized_end=36261
  _TSCHEMESHARDCONFIG_TINFLIGHTCOUNTERCONFIG._serialized_start=36154
  _TSCHEMESHARDCONFIG_TINFLIGHTCOUNTERCONFIG._serialized_end=36261
  _TCOMPACTIONCONFIG._serialized_start=36264
  _TCOMPACTIONCONFIG._serialized_end=36944
  _TCOMPACTIONCONFIG_TBACKGROUNDCOMPACTIONCONFIG._serialized_start=36478
  _TCOMPACTIONCONFIG_TBACKGROUNDCOMPACTIONCONFIG._serialized_end=36840
  _TCOMPACTIONCONFIG_TBORROWEDCOMPACTIONCONFIG._serialized_start=36842
  _TCOMPACTIONCONFIG_TBORROWEDCOMPACTIONCONFIG._serialized_end=36944
  _TTRACINGCONFIG._serialized_start=36946
  _TTRACINGCONFIG._serialized_end=37006
  _TFAILUREINJECTIONCONFIG._serialized_start=37008
  _TFAILUREINJECTIONCONFIG._serialized_end=37076
  _TNAMEDCONFIG._serialized_start=37078
  _TNAMEDCONFIG._serialized_end=37122
  _TCONFIGITEMVERSION._serialized_start=37124
  _TCONFIGITEMVERSION._serialized_end=37190
  _TCONFIGVERSION._serialized_start=37192
  _TCONFIGVERSION._serialized_end=37258
  _TCLIENTCERTIFICATEAUTHORIZATION._serialized_start=37261
  _TCLIENTCERTIFICATEAUTHORIZATION._serialized_end=37615
  _TCLIENTCERTIFICATEAUTHORIZATION_TSUBJECTTERM._serialized_start=37401
  _TCLIENTCERTIFICATEAUTHORIZATION_TSUBJECTTERM._serialized_end=37468
  _TCLIENTCERTIFICATEAUTHORIZATION_TDYNAMICNODEDEFINITION._serialized_start=37471
  _TCLIENTCERTIFICATEAUTHORIZATION_TDYNAMICNODEDEFINITION._serialized_end=37615
  _TAPPCONFIG._serialized_start=37618
  _TAPPCONFIG._serialized_end=41117
# @@protoc_insertion_point(module_scope)
